
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xf3$\x00\x00\x00\x95\x00S\x00S\x01K\x00J\x01r\x01 \x00\\\x01"\x00\\\x02\\\x03S\x025\x03\x00\x00\x00\x00\x00\x00 \x00g\x03)\x04'
        b'\xe9\x01\x00\x00\x00)\x01\xda\x0b__pyarmor__sON\x00\x00PY004022\x00\x03\r\x00\xf3\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00\x00\x0fN\x00\x002\t\x05'
        b'\x00(\xad\x9a\x0e\x17!D\xed+\xf2\xfe\xa5\x15\x7f`\xa7\x00\x00\x00\x00\x00\x00\x00\x00s\xd7\xa2h\xd48=\xce\x10H\x8a\xd1Z\xca\xbe\x16\x91\xe1.\xa4)_\xddu\xe0\xe1\x0b\xc6"t\xeb\xe9\x99\x87\xa6qR3)'
        b'\\O\xa2\x90J\x1c\xf4\x80o\xe3\'\x80\xe2\xd9"\x83\x89\xd5U\x92x\x13RL\x17\xa0\xcf6\x1eB\xf8L+\xd5\x8c\x94\x0e\xd6b\x08\x00V\x7f\xc7\t\x8f&}\xf3\xde\xc3 G a\x93H\x08\xfbF\xb7\x88-\x8c'
        b"\x1d(\xbec7\xe4i\xcd\x12'\x9b\xbf\xb2\x93y\x86\x15QE\xd7\xf03^\xd1\x0bQ*k\xe6\x92\xaaZ\xc9q\xbfPW\x81\xa7x\x0b\x7f~\x1b\xaa\x12\xe7\xe6H\xdb~G\xc0n:&xh\xbd\xfe\xb1\xc9\xac\xd1"
        b'\xf3\xb48\xf3\x90\xe15\x05]\xb4T\xad\x8a\x98O%s\xbb\xd5\x1beN\x1f -\xb1%\xc1:\x85\xc1T\xad4\x8f$\xe5\xc5I\x81\x13\xc8`c\x00\xcc\x89\xa8\xadkf\tI1\xb4B\xe0\xc2(\xda\xdcb\xb9\xeb'
        b"\xb7f\xb6'\xcd\x1d\xab\x94U\x83\xdb\xcd\x86Z\x96\x1e\xe8s\x1bB\x93m\x84.\xcf\xb5e\xf2R\x17o\x8d\x1b\x99\x1fp\xf8\xdc\xac\xe4\x88\xfcy\xe4;\xfd\xf7\xb6\xb3\x12\x11b\xb5\xde\xbd\xc2\x0e_(\x82\x07:\xaeA"
        b"\xf9\xb1\xddf\xae\xc3\xac\xa3\xa3\n\x08\xba=\x1e\x06\x0bq\xd2\\\xc0\xfa'\xfe\xd9\x0f\x93:\x9a<\xf9xM\xc8<+bp\xcf\x99\x08v\x0f!1\x02\x05\xe6\x8c}\xcek@\xa0 \x93k\x83\xf9Gu\x0c\xbb\xef]"
        b'\x9d\xc6\xaed\xd4g\x00\xff\x0c\x87\r\xbc!\xb6\xb9\x07P\xaa\xc5\xe5\xcb\x89\x83F\xd24\xb8*\xdb\\(h\x12\xe3e\x8f\xd8k}\xb1\xa7\xbe\xfa\x108\x13"\xaf!\x17&\x99\x9fo\x1e<\xb5g\x9fq\x87\xdf>V'
        b'\xf5`.\xbe9\xa7\xf5\xfd\xbb\x02\xcb\xff\xd0\x9f\xfa2\xaa\xd0!\xe1\x1c#\x1b\xd3\xc5\xd4\xf4\nRi\xb6\x9b\xa2\xb7\xfa\xb5\xa0\x00\xe7I\xa0\x8a\x8b\xeaQ\xacR\xdb\xc18\xa2\xf6\xecHz\xb8\x05p\xee\xb9O\xf7t\xfd'
        b'\xcc\xfb>\x8e\xce:\'\xb2-X4L\xab\xe4"\xc9Z\xe4\xd6\xac\'\xb9\xef\x90\xfb=\xafu\xaf\xd5\xf5\xf6\x7frQr\xb5\xd8\xa7o\x19\xaem\xf0QV\xd5\xc7x\xbfjG\xd1\x96\t$\xf9~\xc8|JQ\xc1\xca'
        b'@\xfc\x1dm\x13\x91\x17\xa4\xd0\x90\x89X\xcf@\xbc\xd5\x8e\xaa\xdb\x87\xb0\\U\xee`y{&\xdb\x8b\xdd\xdfd\xdeH<\x07\x1c\xbd;\xbc~\xa2!\x153"5\x18Q\x9e\xa3\xa1"\xe6\xdf\xd8f\x1b\xb0\xb6W\x91d'
        b'\xf4\x00x\x14\x89\xc1\xb54R\x9e\xa7\x1b/\xa5\x02Z2\x83\x87 j\x98<tQ\xbe\xdd\x92+F@\xd4\x10@1NX\x9e~\x11$\xd0\xe7\xd4\xb4\x07\x904Q\xac%\x0b\xca\x93\xa1\xc3"\x1e//\xbd\x0c\x94\x1a'
        b'\x10\x03\x00\xe9\x0f{\xd4~VL\x8ef\xaa\xd1Bcu\x88Qak\xaesQ\xe5\x92O\xb1\xe0\xb0Wyc#:!\xab\x87\x05\x13;\x17\xee\xc9\x8c)\xd1y\xbd\xdcH\xfe\xca\x9e\xe8\xdf\xdd`\x97\x99G\x1d\xeai'
        b'$\xb1\x8a!R\xb0\xba*\xf5\xe4\xf7E\x91\xc3\xb2\xeb\x8d-\xf3\xa8O\xaa\xb9\xefY\x0bm\rr\xff4\x9f\xbe\x03Q0-P\x94\xd8\xbf\xac\x0e\x8b\xab\x0e\xedj\x06j\x97->\xd4\xc3\xf6i\x05fRA\x10\xbdb'
        b'`\x99\x8c?\xe5\x02\x97\x1b\xe4\xc5\xc4\x18\x0fQ\xec\xf6\x16\xcb\x0b\xd7\xe2\x056\n\x91\xb0\xaf\x9bd6\xb2\xda]k\xa4\xb9\x15\x9f\xd2\x84\xd7\xe8\x87\xbfN\xff\x11 \xf9\xe5S\xbe+\x07\x94FnM&\x8e\xcf\xdcq\xa1'
        b'T\xb6\x8b\xa7{F|\x80 \xe2\x17\xdd\xa8\xacYf\xe0\xcb\xd9\xe8F\xaf\xdf,2\xd0}\x8ax\x1b\x96\x9a\xd9\xb4M\x15\xdb1\x0b@\xec\x94\x05\xfc\xf0\x9d\xf0\x07N\xcas7QvKQ\x91\xd0\xf6"c\xac\tR'
        b'9\xa5U\x10nqp\x87\x7f\xfc\xc6\x03\xf5\xfb\xe0\xf8\x9cEI|\x1f=\xc0\xf4A\xd0~\x91f\xdcQq\xd8P\xd4\x1br*\xd9E\x9c\xb9"\x8c{\xc3\xe7\x1e\xa3z\x06\'\xa8\xceYt\xb3\x04\xd50F\x9d\xb9u'
        b',^Y\x9d!\xb8\xdd\xb7\xb6\x05\xfb\x99\x99\x9f\xe2pK\xaa\n\x91O\xa1\x95\x8d\x94\xe9\xd9\x829\xda4QzE\xafkt\xa8\xa6F\x7f\xd9\xc1\xe12g\x1a\x04\xa3\x80-\xf4\xaa)\xc4\x9e\x9e\xb8i\xf7\x8c\x80^\xa4'
        b"\xb5\xbd\xc4\x1a\xa9\x10\xe9\xd6\x98\x15b\xc3\xe8}\xf0%\xc8l\xc4]\xf0A\xb8<~S\xb5\x03JR\xd6\xde\xf3,\xe6\x9f@\x05H\x02('\xe9.\x8c\xb7:q\x96\xfe\xa0\xd4:\xe5\xf8T&u-\xec\xfa\x14\xe5\x03"
        b'\xc9\xd9F\xb1\x13t\x9e\x81\x90\xd4\x99J\x04N)\xdc\xd8c\xa5\x893:}\x87\xcfy\x1a\xaej*]\xe1\xbc\x101b+u?_\xad\xc9\x94w\x92\xee\xd6/\x8e\x0b\xfa~\x98\x15n\x9e:\x9d\xe1\xdf"\xc0\xcbu'
        b"\xfa\xdb\x00\xa1\x85\x91\xbde\xd5\xb8H\x0fy\x06\xea66z\x18\xde6\x02\xee\x11\x9d\xd4\x06q\xa2\xa7\x8d(\x9b\xd3bB\xae7\t'\xbb\xd7+\xbau\xd5\xd3T[\x93\xea\xaa\x98\xa1(W\xce\xb3\x95\xe7\xc2\xaddX"
        b'w\xc2\xdb\x04\xc0X\xab\x8b\xda\x86\x92z\xda^\x19\xd4e\xe3\xe4+\xf8\x9a{\xd7w\x14\xf2\xf4\xe2\x87\xcc\x7f\x02\t}\x10Y\xa0&\xb1\xbb\x82\xa3*\xccQr\x86>\x828\x0f\xdcX{\x81\xbb\xe1\xe7\xce\x8e\x90\x06\xdc'
        b"\xff\xf5mE\xe88d\x8b/`X\x006@\xed\xc2\xcc|\x15D\x8a.\x14\xf2\xb3a\x1e\x97\xee\xfc\xc7\xb5\x9d6\xc8*Z\xea\x04\xef]\xce8\xc09y\xde\xbd\xd7X\xa5%'H\x04\xfb\xde\xeb\xcf0Yr=\xdd"
        b"\t{\x92\xc7,:\xbc\x91\xe2\xael's\xe5\x90\xaa\xe6\xe4\xbe\x7fhMS\x18\xe9 \x8f\x88\x06\xd8S\xa5\x00R\x1fe\xb9\x9a8\xb6\xfe\x08M\xf1\x07g\xdfx\x96\xca\xb8l\xc4\xfd\x8d\x0e\xe7\xbd{\x98?\xdb\x10\xc1"
        b'\x1c\x19\x1a\xf3,\x0b\x92%Nm\x8fM\xe2,\x97z\xd8\x19\x8a\xcd\xe2\x9e\t\xe3*\xf9\xdc\x86>,6\x99\t\xdd\x7f\xab\x08\x80\x0c1\x02\x1d\xfb,\x17\x10\xaa\xc0xI\x115\xf0m\xe0\xfew#7\\v>/\xd7'
        b'\x07-\x9f\x84.\xbb\x19e\xa7\x11\xb9\n\xff\xde3=Pa\xc4\xd7\x12l\x0e\xc4\xcf\xc2\x155\xe2\xc9\x1dl\x88\xcf\xa4\xee\xa0?m\xe1\x92f\x10h\xfa*N\xb5\xf3dD\xd9G\xebi1\n7\xb8\xfcI\x8f`\x9f'
        b'f\xb8\xeb\xef\xea}\xec\x85P&\xf1\xf1\\\xdf\x9fr\xd8y\xb2\x8b\xa0\xf0g\xb3h\x07v\xe0\x95k\x8b\xdf\x9el\x96t\xce\x07\x1d|\x1c\x8e\x95?\x89\x1f\x8a\xday\\\x96\xa4\xb5=\xbc.Q(V\x8a\xfd\xc8\x91*'
        b'X\xff\xec\xc6\xfe0l\\\x08s^!lC\x8aT4\xa9\x8f?\x9cK\xa5d\xc7\xbe\x87\xe5=\x13?\xb6\x8d\xf3\x0e6rzl\xcdy\xb3O\x8d\xc8\xa9?A\xda\xb6\xc7hW\x8b\x9b\xe1*<\xbbG\xb1\xff\x8f\x11'
        b'|\xef\xe4\xd3H\xc2\x87\x87p\x04wP\x9c;\xdb\xb8\xd83\xc4M\xc1\xa2\xc8|u)\x02\r\xe3\xecIz\xf4\xda\x906\xe0F(E3\xb3\x9e\xf3\xd6%\x9e|\xedWx \xc1T`\xfb\xf5\xe5\xee\xe0\xfb\xb8\xde\xbf'
        b'\x8a\xd5)8\xa7\xd0\xed\x9f]?\xca5\xbf\x00\xec\xd8\x16\xa4=\xef\x05\x10\xcbIp\x03\x983R \xd8\x84r\x05Kc}\x1f\xdc\x1d\xa8Uks]!L\xd2\x1bc-+\x14)*\xc1I\xbfBuMy\x8a)'
        b'\xd0\x00)#\xab\x11\xab6\x810,\x1b>E\xdf\xc8\xf0\xc4\xe8\xaf\xb8\xc7K\x9c\xe2b\xc9\xa2\xe2\xb9\xde\xa90\xe4ad\xecr\xe0m@\x0f:O\xc9\xb0o\xbe\xe2\xf0<\xbf\x8a\xa9CwuG3x{\xdd\x88\xee'
        b'!s\xc8\xbb\x1eE\xf8\x15\xda"\xab\xfa=\x97\x81\xcd\xdeg\xee$\xf8z2o\xden\xa2\x87\xa2L\x14"h\xff\xcdO^\x89\x8d\x95\xc3\xb7D\x15\x98\xe3!a0\xe6\n\xdcO\xe8\x0eK\xd8X\x0e\x86?.\xf6\xcd'
        b'\xfb\xd1\x17\xdd(<Tm&\xa0zc\x05\xfe\x1c\x9f\xae\x89\x16\x88\xfb\x89\xd08Y\xe4\xfd\xbe\xa9\xb7\xf4\x7f\xe0\xac\x12tZ\xb9\x00\xbf\xe3y\x0bv\xf0~|\xe2sX\xe5O_4\xdbA.\x8ddu\xd4mxk'
        b'\x0bD\x8ev*\xcf_\xe6\x8b\xb9\xad\xb5sU\x96\xab\x1f\x94\xfd\x92\x94yn\x88\x85\x14\x82a\xa5\xe6\x8d\xc7\xf9\xd3x\xe1^.\x86~D\xa7\xd0\xfc\n\xfd\x9e\xd7l\xfc\xa8\x80\xa7\x01\x9cM\xb1y\xbb\r\xb8\xf3\xe9\x9f'
        b"\xd8\xf3\xa7\x0e\xcbB\xfd\xb1ilU\xa3(\x18\xe6ii2\x0f\xdd\xd7\x00iV\xb5\xd15&\xca\xdby\x81\x8c7>\xbe\x11\x85\x14\xc3\x1d\xa7M\xbe\x9d\x85\xaer\x9fi\rw\x92\n]\xeb\xea\x8d'\xea\x95\x8a:~"
        b'\xe7C\xda9d?L:%\xf4"\xec^\x1f\x0f\x02\xbf\xa6\x0b\xe8Ul\xae\xd6\x0b\xc6G;\xc8h\x03\xac*\x87\nV\xf3\xbf\xd7W\xd0F_\x92\xce@?-\xed\xe3*\x8d\x9bN=\x82\x16\x8bP\x80\x95\xd8\x9d8'
        b'Z\xa3\xdee\xbe\xd9L_\xd2\xac\x04W\xe79\rQ\xabt\x1c\x18\xc1$\x1f\xe1\xc1\x133\xba\xcb\xee-\xdd|\xb41\nD\xd4\xc7\xbf\x9f\xa1\x97\tPh\x1d\xb3\xa6\xfc\xf5\x1dV\xa70\xb5N\xe0F\x1b\xd0\xf3\xae\xd3'
        b'\xeaO|\xa8-x+\x96\x1e\xcd\xddZupq\x88\x9b\x96\x90\xe6\x9f\xabpE\xd4NsF5\xbd\xacF\xe8\xf9\x88`1\xc1\xfbA|\xb0\xc1F\x89r\xe1\xee\xfb\xffwa8\xbf\xc9(\x01\x80[\xbf\xdc)\xbfG'
        b'\x13\x90By\xc2\xcd\x84\xd5\x92\xa3uH\xcf\xbfY`>C\xbc\xfa\xd8\x96\x15g\x9a\xe6\x8d\xeeF\x9e\x1c\xd0\xd8\xb2b\x18\x7fHH/s\xd0/2V\xfe.\xad\xfc\x1a\x00\xc3\xa5p2h@\xe4\xbdN\x9c\xe2T\t'
        b'h!\xa3\x1ei\x19F\xa7;\xb5T\xfe6\xd8\xf8m\x880>\x181Y=#\x99\x15\xeb\xcd\xa8^\xcf\x0c\x08\xa1*4\x9e*\x93S\xb9Y\x8e\xc0c\xad\x87Ju\xbfpR\xaf\xeb\x0b\xb5\xaa\xe3\xe2;\xb2\x9dm\xe1'
        b'\xd8\x85e\x8c0\xa0\x04s\xcd?\x1ee&\xdb\xbb\xe7\x19\xdb\x12\xa0Gu\x0c"\xc2\xf8\x19f\x04U\x1f\x0e#\x97\x96\xa0-n\xd7ZK\xf8oH\xf0W\xd8\x1f|\x04\x86\x00#\xf0"+\'\x83z\xa2K\xefg('
        b'nR\xc7\x12<m\xbb\xe1\xe4i\x00\x93s\x7f$\x97\x92\xe5\x1cr\x92\'\xac\x8eA\x8f6S\x07\xe9\x0bHp\xb3k\xa3SZ\xc6\xf5b\xa9\x10e\xb7\x1a\x89\xba\x0c%"T\x99\xc5\xf70\xc0]\xc5`4#\x95\xc6'
        b'\x9d\x8dl\x93}*y\x9c\x9am8]SU1\xda`\x81\xe2}\n\xae\x16\xa0\xaeI~\xe2\xfc\x92v\xb1\xf8\xed\r\xe0\xd1\xa3j/\xd2h\x1d\x88\xf45\x1cL\t\xf2\xf3u\xe8\xc2N\x93Y\x12\xf2\x8d\x06[\xd9\xe9'
        b"I\xa7\xbf\xacR\xce\xe1'Ou\x18\xc5\x8c\xdc\xdb\xec#VH\xa6~\xec~\xecj\xc9\xbe5\xbc~\xbf\xac\x1d\x00\x8f/a\x9a\xf3w-\x92\xfd\xe2@M}\x1cZ\x10\xdea\x86\xdc\x17\x9f\x06X\x84T\\\xe7\xc9\xf2"
        b'\xc65\xd3\xffr\x04\xc6\xf9\xe3h\xf9\x06\xf9\xcekj\xbb\xb3\xe7\xa1H\xd4sYbt_\x83&\xf5\xb2G*Q\xba\xaf\r\x83\xab\xefj O\x11\xad\x83s\x1e\x15.N\xee\x9f\xea&\x15:[j\xb1kG\x89\xba'
        b'P\x1e\xd5\xec\x9abBc\xcfY\xe4\x13\xe5\xce2\xed{=B\xc9\xe2\x0b\xeeF\xa6\xc7\x03^\xe4\x12zT\x84\xe9\x01 \x10#u\x11\x06\x06b\x8e0\xcf\xe0\xa3\tGo\xdd*\xa0\xb7p\xd4%\x18\xa4\xd4M\xa9\xcd'
        b'\xb3\xc9\xfel\x05\xf5\x9b\xcf\x1e\x1b\x17O\x02\xcf\x7f\xeao"a\x0c\xb50_\x18=\xc7R]\x01\xe4]\xa0\x1e\xdb\xbe\xd1\xce\x8b\xf8r\x04\x9a\xda\x1d \x0b\xf4\xb0\xe8\x7f\xedG\x1a\x86>]\x87\xe9\xa06\xd5v~A'
        b'B"ll\xc4z5\x7f^\x99_\xf5/\xef\xe8\xbe\xff\x0cO\xf5\xc7\xae5\x13s\xa4\xd9!\xb3\x8a~m\xaeZ\x81\xccU\xfd,pI\xa8K\xc7\xca\xbeo\x89\xbetb1\xd2\xd8^\xfd6\x03>M\xb8\x86\xfb#'
        b'\xc2\xa2B\xf3\xb5\\>\x08\xee\x9bP\xac\xbeZ\x86\x7f\xf1QX\x1c\x02\x04^\xf9\xf2xu\xac\xfbk\x03\xc1\xab=\x90VA\xbc\xc8\x19\x14\x99\t\x87$kh*\x94\xc2\x11/\x98\t\xb1\x13\x8a\x15\xc9y[/\xdfd'
        b'\x00!\xb3/\x05\xc6\xcfj\x18]\xb6\xb1\x92\xe6\xa2_\xe7\x9fx\x1f\xa9\xb9\xbb\x9fi\xc9\xd7\x93\xf7\xea\x17R39\x97U\x1a\xe8\xd0\xc4\xdf\x9bv%\xabI\x0e{\xe8\xdf\xf4\xb5.\xfaB_\x93Q\x94\xfe\x96i\xafd'
        b'3\xd5\xe4\x95\x93^\xcfG4<\x12\xec\xd0\xb4\x17\x90\x827\xd5.\x90\xcfx\xac\x90\xa8~\x018\xdc\x98P\x85\xab\n\x8f\xb6\x1e\xe3\x83m\xf1\xc1\xd1?\xa2\xf1\xb9\x80\x11\x07\xae\xce*)RYt\x9f\xaae\x11\x13\xc0'
        b'\x17\xdfh\xf1\xf1Loz\xe0\x82_\x83: y\xdf|\x9e\x92\xd9\xe7\xfd\xb0G\x9d\xade\xech\xe6\x1a\x0f[\xfe!@\x8f\xfc\x88~\x08\xa5H\x80\xd3\x07\xebc\x93\xe65\x88bs\x10\xe07B\x91\xa4\xd9\xb3\xa7\x16'
        b'\xdc\xb0\xb4\x17\x86\xdf\xa3RR\xe2\xa9\x8c=[\xc4_l\x08z\x9d\xf0\xbd\xd67\x8f,v\x1d7\xf7\x7f\x91j\xf0I\xce(k\xdab\xb7F\xde\x1a\xb4cf\x1d\x06\xe7WD\xb5\xfdSC.4"\xc9Ga\xa8J'
        b')H\xf9\x1f\xb8\x19++C\x82\xcd{):\xe4\xf0\xb1\xb4\x16\x94c\xae\xfa\xf3\xdc\x95\x1c\x97\xb4\xf4\xe6\x8b6\x8a\xf1t<B\xd8@\x14\xe6|\x9a\xdb\xc9\xfb\xbb\x8c\xd0\xae\xfd\xca\x92a\xb3s9\xea\xb7-\xda\x9b\xfb'
        b'\x81\xd4\xc9\xb5\xb7\x8e\xb77\xa9Z\x9bh=\xcb\x8f-\x82\xda\xb6\xe3\xe8>\xa3\x94\x19\x0b>\x82\x8d%v\xac\xc9\x93\x8dq-E\xe5\xd0\x87\xe6Y4\x11Z\xaag\xa7\x0e\xb8\x19\xf4{\x11\x10r\xba\xd87\x83\xb2x\xb1'
        b'\x8c-W\\\xd3W\x86\x92\xf9\x13\x863\x80\x8c\xf8\x17&_\xc5tP}\x1a\x7f-\xb6\xc4\xa1\xb3\x05\xf1`\xe6{\x14\x90\x98\x0f\xd64\xaa\xdc\x83x"O\x96\xe8\xc9\xf0=$\xf5\x8e\xe4\x8e\x15<\xfa\xd6\x99\xe4[\xd1'
        b'(*\xb7>\x9cD\xc5#:\x9e\xf5\x9c\xab\xb5\x1fw5*\xdd\xe2j_\xc9\xd6A$~$\x84)\x9e\x88?27R\x1dF\xbd\x848\x04\xe4b\x03V\\=n\\\xcb\xe2W\x9b\xf3\x8a\xd9\xdf\xeau\xb9\x9f"M'
        b':\xb9"\xa1xk\x11 \x9c\x0ca\xbc\x1f\x8b\xbeU\x06\xc2\xcf\x84\x06\xbah\x83\xe2\x81t\xa0\xb3\xf8\xf5\xd3\xe1|\x8fm\xfa\xa9.k\xcf\xe3\x0e\xa0\xaaq\xeb8\x95Q-/\x07r\xeb\'\x82V\xf9(m\xb9\x8b\x1c'
        b'j\xbf\xa8\xb3\xe5#\xd1\x99\x1a\xca\xf7V/\x17\xd4o\x08\xd4\x01\x83\xba\xb4%FR\xc7r]\x14\x84\xc8\t\xff\xdc\xe5V\x11H\xf9\n:\xfa\xc0\x96\x9b\x9e\x19\xc5LS\xa6\xe5g;\xade-x\x10\xae\xb9\xf2\xffO'
        b"\xef;\x07\xec\xe3\xd7\xaf\x9e8~\xca\xa3\xb63\xa6\xe9\xad\x13Y^\xd9\x9aZ\xc0\xbf\xb9U}\x8ae*.\xd2\xb5\x0c\xd8\xba\x9a\xe8'm\xfc'M\x9a\x8d\xdc\xfa\xb5\x19\x0f\x9f\x0c\xbb_>\xb3aa\xdd\xd6Bg\x84"
        b'\rd"\xd3\xb7C\xb8\xb3,\xa6\xc9EA\xbb)?\xaa\xa0\x908F\xb3g\x1a\xb3r\xdc\xc4?\n;5\xa8$\xc0`_\x7f\xf6\xb0l(\xd2\xa6\xaf\xaa\xaf"\xf5\x06\xd31\xe2\x86@\xd3\x12"\x10\x9ci\xe3{\xb0'
        b'\x92/\xd9\xa7d5\x16G\x7f2E\xfdW\xde\x95\xd6@L=\x07\xd0+\xb2\xc0\xe4\xe6\xde\xc0\xe8\x96\xa0Xa\x87\xa4\x17|2L\x11C\xa6\xcbF\x87\xf9e\xdd\x05U\xc1\xf5\xb5\xcc\x0e\xd5&\x97\xc6\x8b\xa0\xc0\xd2\x07'
        b'\xdd\xe1\xbc\xf8\x06\x05|AS\\\xb3H\x05U\xf2=\x82\x93\xa6\xd3+\xddrvVB}X.\x80.\xd8\xb4\xfa\xf8\xe4\xf2\xb0X\xf0\x91"\xbdpS\xfc\x8b\x99G\rL\xb3\xdf\xe7\xca\xcc\xa8\xff\x95\xa5\xa5\xdf\x0eK'
        b'g|\xf5\x82+\xaaa[A\x92\xd7Mj\xc63\x80\xec\x88e\xfd\xb6\xfe\xfb\xd3{\xbc\x06xqy\xd3\xd3sS\x05<@\x90\xbb\xfe\xe2\xec_\xf7d\xd4Z\xc7\xa4b\xdc\xb1\x84\x99\xa8\xa6\x12\x99\x12p\xb8\xbd\xb9s'
        b'FF\xf1\xa4\xebW\x8cmu.V\xb4\x87\xd7I\x04\x19\x9cU\xa4 \x83\xd0\xf7\xc1BT)J\xfa\xe2\x9d\x81\xf5\xb5^\xde\x1c\x9a\x1b\x89:\x8f\xf6\x15_\xa2\x9f)\x8b6\x10\xbb\x9f*<\xe2\xbfA\x8dzzg\xcb'
        b'\xb8\x1cN\xc0c\xd0 \xe5\xf1\xa6\x0b3\xfeld\x82oh(\x99\xd5\x01\xb1\xb8i\x06\xe9\xfb`\xd4\x05\xe3u\xc5\xb8\xaft\xe1l\x9e \xd8\xe3,\xc1SS\x98\xd0\xeeK\xef}s\xb8\x03+\n\xa5\x94\xaf\xdaK\t'
        b"\xbd\xb6\xc0>\x12\xea?\xe9xUx\x14]e_\xce9\xf7\xd1\x1e_\xa3\xf1\x11v\x13\xde6\\\xed>\xd3\xef\xb1I\xb7\xedn.t\xb0\xdc\x86'\xcb\xd7[\x96s}y\xe1\xa2\x9d\x95\xcb\x7f}A\xb7\x94\xa5\xf5\xb1"
        b'\xeb\x11\x8f\x83KGf<I\x1d\xbb\x85\x184\x19\x84\x02\xefs=)\xab\x1b\xb6\xa0\xe3o\xe3\xec\x98$\x88|@\xff\x0b_T\xfek\xba\x93\xb2[\x863\xb1\xda\xd7\xa2!JD\x90\x08\xcb\xf3\x02\x93\xa0\xe5\x0c\x95{'
        b'L|\xbd\xb2\x9dE\x12\x03\xca\xb4\x082};\xf2u\x19\xfe,\xec\xd9jAs\x02\xb7\xc3BWi\xc8\xe2\xaf\x0bA\x88y\xcbtdL\xef\xb1\x06\x0bk#\xb2\xf1_f\xb1k\x18\xb3[\x97\xe0\x8e\xc4\xd0\xb1.\x90'
        b'\x8c\xeeV\x82%\xd5\x97j\xe1B\x89\xb6\xee\x8a\x9e<\xf8\x86L\xdeCCB\x8b\x97\xd1L9\xc1\xde_2\n\xeaB\x07\xe7\x14\\\x0f\x0f\xf7\xa1\xa2\xb2\x12\x80\x81\xc9(\xad\\8\xd2\xc0\x0b\x19\x82\xc2\xc6\xf7\x1c~\xcb'
        b'\x97s\xf6\x93\x9e\xe8\xac\x07?\xff\x89\xb1\xeb\n\x9e\x19`* A\xa2r?\xb0\xbe\xb0\xa0\xf1u\xd7\xa7\x00\x07\xad\x1b\xfc\xfb\xffjQ\xd0\x0b\x16(\xa2\xc8\x914h3\xed\x015J\xd3\xa1\xb5k\xd1\xd2\n\xf1\x92U'
        b'\xf3\xc1\xa7\x02\xb4\xd8\xd4\xfc\xe9\xa7\xd1\xfa\xd8\xa4Go\x89S\xf1\xf3\x18\x1e\x97*^\x17\xa7\xa7\x8a\x10Z\x14\xee\x8fr\xed\x82\x92\xb2\xa1[pf\x8e\x94)+o\x8fZ&\x1a\x8eHNH\x1b\xb4VD\xf1C\x93\x0b'
        b"\x1b\x1a\x8f\xda\xcb\xebE\xa8-H\xf5\xdd\xc7\x05\xc2\xcc\n'\x89_\xd1m\x8e\xa5\xf7\xcamL;E\xe0\x92-8{\x1f\xeb2!\x11uPw\xbe\xbc\xdd:xG\x83\xb4~,\xf2c\xa1\xb86*\xc1nh\xd4\xd3"
        b'\xb3\xa2uuI\xfdW\xf0\x9cm=Gr\xb4\x8dg\xa7\x07\r\xf7\xca7V\xa6\x9eXj\xeb\xe5\xe4\xed\xb2\xb94y\x1e\x81\xabx\x88\xf8\x1c\x14\r]\xfc\xdb|b\xa42^S\x94\x19\xceR\xbf\xa3K\x13S\x14\x83'
        b'H\xec\xda\xd1\xef\xd0\x9e\x04\x8c/?\x1a\xc0-3A3\x8c\xa5\x8b\xc0T#iy(\x08x\x0eN\xda\xc0g\x13.Ym\xc1\xfe\xf2!\xa4\xcc\xbe; \xab\x134Fd!8\xee\x85`^\x05<\xe4\xe7\x8c\xc8\xf7'
        b">\x04\xae\xcb\x1f\x9e|zE\x0c\xb3\xf0\n\xefM\xeb\x80l\xed\xf0'\xdd\xd4\x89\xe0\xe0d\x80;oN\xa3\xb8\x05\xc5~\x94\xab\xf0F\xc5`\xcc\x96_\xf7z\xca\x14\xd4\xb69}\xfc\x02K\xc3\xce\xcf\xab~\x88,4"
        b"J\xc1|\xe4,\xd7\x02\xf2\x90\xb3\xb4&\xf0\x95\xb1\x05\x92\x9c\xed\xf6\x8d\xb2=\x99\xb6Q\x9e\xe2\xb8\xafB)E\x8e\xaf\xba\x93\xa9+w\x1f\x0fK\xdf\x80>\xa4\xdd\xd6*x\x08]\xda\x19'\x95\x9e\xce\xa9&4\xf4\xe8"
        b"K\xcb\x8b\xc9S\xcc@>\xbb]]\xa3\xe4\x85{\x0f\xa4'\x1d\x0e\\k6\x01R\xfa\x89\x99UJ4P\xe7n\xce\xcf#\x8c\x9b\xf3\x1ehp\x06\x7fY\x8fY\xe9\xf6\xae\x9e\x1dA\xf5\x88\x19\xd0~v\xdd\xfc\xb5D"
        b'\xd1,b\\@\x86\\\xce\xc6\x07\xc1\xba\x0e|k\x97\xc0\xc0\xe5\x10\xdbh4\x89F?\xf1\xaeY\xa8\x8d\xa3\xebSq}\xfb\xb5\xd9\x9a#A\xc1<\xa5-Y(\x0c\xa9\xbc\xfdc=b\x08/\xb22\x98\x1e\x18/<'
        b'C\x7f\xdb\x8ak8h\xe8H\xfblhK\x16V\xedw=\xbb\xced\xd8\x9c\xd28\x01\xbf\n\x83S\x05n2ahj\x88\xb7\x14s\xe5\xd3\x92\x90\xac\xf5i/\x01n\x98\xa4\rF\x1e\xd2\xec\xb9\xfe\xea\xd4+\x93\xad'
        b'\xbbo\x9f\xadt<1\xa4\x976\xceh\xca&\xba\xcf\x05f\x05\x98l\xfcP(\xd7\xe2Z\x9f\xcb\x15\x8a\t\xa3\xa9Tp8M)cy\xaeaa\xf4\xe7\xad\xfe&\xe1\xd6\xbf\xb9\x08\x90\x03_\xd23g\x8e\x90yy'
        b" \xac\xe3TX\x04\xdb\xcfL\x0e3\x9d\xa1\x9f\xff\x05\xf4\xc2\x93f\xdc\x12\xfaby\x81n\x95eq\x83\xc1\xe8G\x96\x15\xc9t\x15A\xd8\xa0'\xc6\xdb0F\xf7\xe2\x991\x9cs\xcf\x99\xf9\xaa\xddZ\x95M\xed\x0c\x8a"
        b'\xf3;\xa1\xf1DbN\x8d#\xa2B;\xa5J\xf4\\\xfd\xb7l\xda\xc2\x97Y\xbdN"Tt\xe1?\xe9\x0fFQ\x85\xad\x06\xb69\xef\x1fF\x1dk\x12vY\xa2s#\xcf\x81\xd2\xcb\xec\xa7\xa7\x7f\x1a\xf3\xe8~\x05\x84'
        b'\xc7\xda\xaa\x84gy\x0f\x9e\xec@\xa7V\xb1\x12\xb3\xc7\xba\xd3\x94:\xe8\xf8\xc4\xacN~\xffd\xcbI\xa4\xe0\xd0\xbd\x9c\xa2\x0c\r\x86g\xde\xfe\x91\xfc\x00n\xa0\xd2n\xd1\xecT\x92\xdf\x86\x1e\xca~\x957\xc8\xf1\xe2H'
        b'\x12\xeeuU!\xd0\xecn\xcf\x83\xf2"b\xb4eK\x9c\x7f<\x7f\x9c\xc6\x9e\xc3\xb5\x10f\xd8\xa7\xf3\x95\xbc\xd3\x01[\x94~\xe2Axp\xf6\x8f\xf9\r\xa6\xf3\xd1d7\x8en\xa1^\xf7\xdc\xc0\xf9\xe9\xdb?\xe2J\x07'
        b'\xc0\x00\n.\x03\xfc\x1f\x85<k\x10\xb9\x83\xda\xf8\xef\x15]\x9d\xe6\xbe\xa0\x01\xc0\xdd:\xa0\x14\xe79\x00\x04\x10Q\x99\xfb8X\xe5\xd2\xfb\xa5\x94\x19\x8bg92\t\xac2P"\x83\x8d\xe0\x9f\x81\x01\xaa\xdd\xd5\x80\x81'
        b'\x8c\xe4\x1e\x9d_\x03\xe9s\xabX}\xf5\x945`\x16;h\x9f\xb6\x83\xcag\xff\xbbb\x8d\xd1\xf1Q\x1b\x9f1\xca[,\x03X\xfb\xf1\x81\x03Z\xc5t\x02\xba\x9e\xa3\xf3\xb55x+\x8c\xf8\x81\xed.\xe9=E\x9eL'
        b'*^,\xdf\xa4d\xe8T\xaa\xe3\n\x92\xfe\x16S\xa7\x87\x0bk\xda\xe6\xa3"\x8b^\xbe\xe8\xcbc\xad^\xf4\xb4\x7f\x9e9\x95^-\x02Tm\xd7"\xff\xb5\xb6\xee\xf3,_\xfd\xa1\x17w\\\xf4\x9b\x91\x15\xee#\x19\x16'
        b'\xdd\xc4\xb4L\x0e\xbd2\xbb\xa7\xb9"\xda*\xda\x10\xcb\xad\xe8\x8d\x15Wb\xad\xdbr\xa5J\xd6\xf3\x8a\x82\t\xcb\xfc\xdav\xc6\tv\xc2\xd3/\xaf)\x897\x03"wYRR\xd5\x12\x81\n;i7\xc7[\x94JH'
        b'\x1c\xd4\x8b\xde\x12\xd4\x07\x86\xbe$=)w\x88j \x86\x9d;\xa6\xae\xf7O\xb7ug\xab\xb2\x86\xf4@\xbb\xe9\x01\x8ff,\x93\x02;\x9e\x19c\xeeY9&\xd8O\x95\xd6\xfc\xa3\x81p\xa6k$\xdf\x14\xd4__}'
        b'\xe6X\xf6\x93\x85=)\xc3\x9cf\x03\xe2\xba9\xd6\x047\xbf\xd1%iD\x01\xa8\xb4\xba\xd8`\x80\xe7\xecX6=$\xc9\x8erg\xa9\x81\x19JG\xe6\x9d}Xg\x9c\xbe\xf4s&\x81\x9d\xa9\xd6\xd9\xfdE\x97qy'
        b'\xa2h\xc7q\xa7]\xe46\xa5\xd8\x83\x02n\xe7\ti\x11\xc1\x9di\xf7{F=\xbb\x8b\x9a\x92P\x9f\x03\xe5\xe1\xd8!C\xe1\xab\xf9\xd7\xb3t\x91\x99!\xd0o\\\x8a\xe48\xda\xc0^uO6\xd1\xa0\x18\x12\x8e\xf5`'
        b'\x02\x05\x8e\x08\xd7\xd8|x\x88A\xc2=\xad\x80n\t\x18\xba\xa80\xcc4=N\xe1\xd6Q\x07(\\\x0b\xa6\xf9\x1cjcK](<gd7\xa0\xf8\xc4\x06\xe2\x83\x9d\xc5\xbd\r\x9c\xb4\x8f\x1d\xed\xed\x19W\x00\xdaV'
        b'&b&-\x9e\r\xdd\xab\x87C\x1f5\x8c\x0f_\xecO6\xfa\xd8T\xc8/*F\xa3\xfd\xd0\xaboac\xe6\xe0\x08\xb4\xad\x82\xeb\x913\xe4\xf0 \r`\xf2xc\xf4\xb1\x9d3\\o\\\x9b"\xcb\xc1ebn\xe8'
        b'\xc1\xa9\xb6\xf4\x86\xca\xf8\xe5\x98\x7f<\xa2M\xd6/\xc6O\x97\xa2\x010\x98@\xe5+.\x8e\x98L\x88\x90\xb7\x96\x85J\x8f\x0b`\xbc!\xc6T\x9e\xea\x98\x04|q\x16\xdd\x1as0\xc1\xe8\xa0\\\xa7\xb1\xa3\x19_\xe7n'
        b'C\xddi)\xb1\xf2\xf4{\x00\t\xaf\x10\xa4\x11\xa7\n\xa3\x01\xde\x85\x17\x16\xbf\xa4\x1a\xc6\xa98\x91\xcc\xd8\xd4\x91\xbc\xbb\xc4\xdf\xdd\xd1\xe0\xc4\xb85N7\x8d\x8a\x1f\xb27\xc5\xd4\x03\xfd\xd3\x88\x03J\x9e[\xd4l\xfb\xb1'
        b'\x81D\xe7S\xd4p\x8b*$)\x81\x86\xa76\x01\xd7pI\x83\xa1h\xde\n\xe4\xa3\xa8\xef\xb6\x897}\x93]\x88\xb1\xff\x05\xab6A\xbc\xe3\x84[\xa8\x8d\x8c\xb5\xfb3\x83\x0b\x1f\x8bl@\x00\xe4\xc2\x9c\x01\x9e1*'
        b"'\x85\xb4\xbf\x13t\xe0\xb8\xa9\xce\x0fGm\xd2\xdf\xe8\xb8\xd9\x98y(V\xcb\x94)o&\x93yc\xdf\xa8g\r\xb7\x032\x9d\x83\xc7\xa1\xbe\xf3\x8aCf$}\xb7o\xe1B\xf4\xd8\xd5\x0c,s\xf1\xfd\x9b\x142I"
        b'\x81c\x9c\xbaw\x8a\x88\xa6h\xb0\x8ax\x1e=MY"\x05\xc52i>\xe6\xe9m|\xfel\xaf\x04p\xac]\x13m\xf1t\x9a\x7f\xd2\xa8\xa9$-\xcd\xfc\xe7"E\x0f\xc9\x98\xc7\xb94a\xae\x03t\xa0d\xc6\rF'
        b"Y\x118xV\xd9\x12\xd2I\xa2\xa8\x8a\x8d\xbf|%O\x1b@KFl#>\r\xbd\xdbO'Dm\x0f1\x99\x913I\xabo\xcf\x8f\xd7?\xc3\x99\x1d\xe4|\x90M>]\xcct\xd5\xf9\xf9/\xd4\n\x90>\xeb\xe2"
        b'\xf4\xc5\x8d\xb8\x0b{\xfb\xa5\xb9\xe3\x03\xf92\x15\xd7\x9e_\xc2\xb5H;\xb9\x82\xc1\xb9r\xef\xdb\x051 ,*\x81\xb6}\x17\x12rM\x848I[\xe1\xc1\x0b\xdb\xe44U\x1f&\x99\xa8dy\xd8}W\xc1\x98\xefv'
        b'4\xd9\x1dQ@\xfa\xd1\xaf\xdfD#\xf6\x06uVA\xd5W\x01\x10\x1f\xdb1Eu"t\xa5\xbcWpQc\xef\xee(\x9b\xd7\rD^\xc4iV\xb6[\xa3\xa3\xb4\xae\x82\xd0\x15\x93}\n\xd9rsM\x01\x00,\x19'
        b'\x9e=x\x88Q\x96F\x008\x97\xe0\x15u\x9c\xe7z\x95\x82.\xf6\xd2Y\trM\xd3\x0fQD\xa1\xf1\xec\x99\xcd\x03\xb0i\x9a6\xec\x9b\x10\x9c\xb6~\xdeXk\x9e\\\xbc\\\xb4P\x85q\xf9t\xaf\xc3\x10\x05\xfe\xe8'
        b'\xbd|_\xa8\x92T\x8eaG\xf59\xc1\x87\xe8u{("\xda\x9d=\xa1\xf4A\xe9D\xc4\xfeR\x1bW,\xb4Ae\x94\xaf\x0f\xceVJ\x15\x85i\xab@\x94\xd8\x12\x0e\xedk\x976\x9f\x17A\r\x15\xc5\xb7P\x19\x7f'
        b'\xe6\xee\x1b\xe1\xe8!\xb0\xe7\xe9j\xe0Zn\xb7\xfc\x95\x14\x10\xfe>\xb7S\xf4Z\xddN\x9c\xf2\xba[\xbf\xf1\x81\x8c\xf7\xb5UOH\x01\x99\x8fi\xffC\xc9\xf4O\xc9\xcc\x17\xb3\xb8\x9d\x1cEo\x1dW\t\x0b>\x05`'
        b'\x9bfeEZ)ER\xfa\x02\xd6@\xa9X\xb0;\x07\x8f\x8a\xd1R\x08\xd5\xa9V\xcb\xb7\xb41$}\x92\xe2\x0f\xa5_\xd5\\\xeb\xc8\xf5\rW\xeeu\x8a\x00yN\x81D\n\x174\xd1\r3w9\x1b\xfe$\xcb{'
        b'\xd7{\xe1\x02TJ\x03[Q\x13u"\x81\x1eq\xeb\x8fv\xd2N \x8d\x89\xec\x0b}!.\\\r75\xc4/Km\x93-\x1e\xdf\x97\xdb\x13\x19\xff)\x95,\xadZ\xc9(\x9bI\x1c-\xd6\r\xa8\x19h9\x05\xc3'
        b'\x98\xf2\xc7$y \x1b\xda\xd9\x87\x89\x8bV,\x82&\xc9p3\xedQ\xa2;\x80\xf1t\x17$0\xeb\xb4\xf7\x8c\xf9m\xf9\x13\xc7\x97?=bs-\n\x92\x9b\x9e\x1e\xb3sT\x9bU%\xb4\x99"yX\xe2#1w'
        b'e\xe0\xa5\xfa}Y\xfb`z\xbb\x1d\xc62W\x1d!X\x81\xaf\x82itI\x1c\x18\xd4\x93\x9e\x1fV\x8d_\x1a"Q\xf7\xca|X[p\x18+\xaf\x9e\x0f\x87\x06{U\xf2r)T{\xa5\xa9\xba?\x90\t\xaf*\xb7'
        b'\xae\x9f\xe2\xd8\x17\xd5\xf5R\to\x97\x02Q\xd1\x80\x87\xdc.=@i\xa9\x15^\x88\x04\x81\x81\xc4\xe9B\xb4\xb0@\xb0\xe7\xe2\x93v\x93\xc0!^S0\x8a\xb8F\x8b\xc6;T\xbd\xa8\x7f\xa8\xa8z\xdc\xc3\x1e\x06\x8d\xc0'
        b's\x99B\x95\x94\xbb{gm\xc7\x9b\xfc\x14\nF\x08\xecO\xa2/\xfc\x98uy\xacj\xf6\t\xb1\xa4\xd6\x18\x1f\x0b!\xde\xa0&x|\x1b\xc8i1\xa3\x93\x9f\xc3q\xa9D\x14\x06E\x8c)V\xcc\xe6\xf5\xd7\xc6\xb9\x83'
        b'\x93o\x11\x0c\xba\xdd{u\n=l\xb7\\\xb3\x8b\x19\x99\xb8\xda\xa2\x03\xd9\x01\xde,\xee\x0b\x85\xc4J\xcb%\x9c\x918\xe6\x9b]\xad;\xe8\x9br\xe5\xbf\xba\xb7\xd3i\xa4\xca\x9a\xb2\xa7\r\xca\x1f\xe0pH\xe88\x9a\x80'
        b'hAv,\\\xccA\xa6\xb1\xe3$\x84tV\xf7JD\xd7\x914\x81%\xe1a#\x0e\x85\'\x8c\x7fs\x9cb\xa6\x11\x7f\xbe\xa1\xd4\x10w),"\x96\x9am\x05\xf9p\xe0\xc7\xb6\xbf&\xb2~\xe6\xed\xe5\x818\xb1\xbe'
        b"\xd7\xfe\x86\x84\xed\xaaC\x16\xd5\xd6z\x1d\xf5\xc7\xd3V\x96\x07\xccQ\x12j\x17\xbe\x9fUc\xb878v\x85#\xd1\xfaHz'\r;\xbc5\x8fA\x9f\x00\xa9\x97&O\xe9\x96*eo\xa4^~\x8a\x06\xdd\x0f*\x94"
        b'\t\x19\xd6\xc2\xcc\x03O\xff,n\xc2\x1b\xf8\x07p\xf8\xfa\xd7\xab+\xa0\xcf\xb9\xe9|\xe3\x84\xe8P\xfe\x92\x01\x10&\xdag\x07\xd5\xb86\xde\xc4\xb3\xd7\xed\x9f\x05\xb9\xbe\x03\x90\xed\xb3V\xd2#R~\xa2\xac\xb3\x0c\xa6\xd3'
        b';\xa5\xa0\xe0m\xf4I\x1d\x1bvF\x0c\xb3\x19/]\xc1\x1a\x12\xa2\x1f\xba_\xc4c\x83\xa4\xf2\x99\xd7\xeb\xec[|\x11\x03 \x87\x18\xfcZ\xde\xd7\xe8\xefd\xd5\xee\x0e\xc8\x13\xb5\x0f\xf0\xa9\x02\xc6\xad\xdd!\xef;#\x1c'
        b'\x9c%\xc0\x13\xe3eV\xf6\xcf\xce\xb2\xc6\xb0\x08\xc2\x86\xfe\xec\x99\xbd\xee:\xf8\x87J\xdd\xc3\xf8\xe1\xdeYX\xc0?>!f\x83\x07>\xc86w*bL\xe4\x8e \\r\xea\xe1\x8as\xc4\xa5.?\xfbr\xe8V\xf3'
        b'\xcc\xb1\xce\x83/\xfd\x80\xe9?}\xc3V=go>\x9ax6\xc3\xdc\x94\x0cIa\x13}\x95+RB\xf3n\xdb\xd6\xb4\x18\xe7y_\xc5\xfbU6\x9f\x00\xcfpY\xcb\xbd\xac\xa6^\xf1\xf2?\xa5\x83\xc6}\xef\xb6\xf2'
        b'\x92\xe6+R\xf1\x1f\x02bR\xca*\xae\x8c0\xd5}\xe1J\xde-\xb2CwfD.x\xddg\x02&\x01\xc2\xed\xbf\xe7\xa1x\x0e\xa8\xa8,\xe7\xb0t\x1cG\x86\xf8\xde\x88\xfe&\xdahS6\x99\xaay]\x97OQ'
        b'\xc2}\xc3\xf5\xed\xb2\xf7t\xc4\xebGI@\xc4A> .\xb3\xbd9uN\xda\x05\x17\xe0Q[\xd2\x9e\x98v\xfd\x8b\xbe_\xd2\x95\x8fu.\xdc\x039\x85\x15%:\xa9\xban\xb4l mwy\xed\x07}\x12\xdeM'
        b'\xd5\x06\xdc\x96\x15\xe1\xc6g\xe5\x0f\x80a\x8c\xd1\xd7\xf5:1\xec\x9a"\xa8\xcb\xd0\xb6m\x8a#H\x8c\x9cf\x03e)\x7f\xf0j\xd8\xd86b\xf2\'f\t\xe9\x06\xdfd\x14\xdfT\x99bdk\x1a\x8a\xb9\x1a\x1b\xe6\x82'
        b'F\xb3jk\xb3\xce:m\xbae5\xa8\x07\xa0\xd0p\x85L\xc5\xa3\xf63\xc9\xab@\x07f\xcf\xd7XO2\t\xecT\\\xcavh\xa8\xb2\x07\xa4\xd3\x00x\x96\x13\xc5\xa9\x004.C\xd5\x7f\xd4\x88\xb5\xc0\\h\r;'
        b'\xe4\xf3\x93\xf1\x94\x80\xf8\x1a\xa6(O@po\x84\xfd\xfd^\xc11U\xd5\xb0\xa7\xca\x83\x8c\xebr\x15\xe2\x02\xb3#\xe3\xa2\xb1p\x9b\xcb\xb4\x9a\x03\x9a}\x8d\xc1\xc1\xd9bM\xaf\x03\xc0\xa3\x95\x06Z\xdb\xba\x1c\xb7W`'
        b'\xc0!~\tV\xb1R\x18\xf8<Fk\xd6\xb6\xb8M\x13jB4\x99\xf8\xd4\xae\xf0\xa41\x0cc\xaa7~\x7flo\x9f\xd4\xaf\xafL\x96\xf7H\xea$\x88\xd27\xf3\x13YDs\xb8\xc0R\x89e\x02\x86\x85I\r\xdc'
        b'\r\xdbB\xd1X-\x97\xdab[\xb0|S\xc7Ne8\n\x88\x98t;)\xc9=K\x80\x02\x8cG\xb6\t3\xac\xc3zny\xf9f\x83\x11y\xf2\x80\x1b<\xa9\x1f\x9c\x9f\xe3t\xd5\x80TV\x93di/\xd8\xf9\xd3'
        b'\xdb\xfb\x96T7\x06\xfc\x89\x1c@XcW\xb98\xcd\xb8\xc9\x12\r\x86\x88V%\x0f\x91Ht\xfb\xd5\x1bU\xe5\x17\xa4=\x905~5\xf7T\x89\xd9\x8d;\xeey\xf4\x06\xdf%\x88\xee\xf2\xaf\xbd\x16\x16\xfa\x8a\xdc\xe6A'
        b'&\x1c\xe8^\xebk\x0e\x1e\x83\xda\x90{\x11\x7f\xa3\xcc\xba%_\x90\x9f\\\xa0M\x93\xd5\xa7\xbd\xc2\x02\xb0$\xd1\xf0i\x98o. \x8d\xe82\xaf\xf6:\xf8%\xdbI\x85\xe8\xf9\x8e,\x06$Fok\xb1\xf3a\xa3N'
        b'Q\x92\x1f\xc6\xe5C\x96i4\xe8\xc1$x\xb3R\x8bZ\x8b=~\xa16\x15\x87\xed/L\x9a\xa9U$q\xc81\x02C:\x9d\xb8\xf8BC\xdeP\xed\x15\x11Y\xcc\x8cP\n\n!j\xf6\r\x97\xd0\x9b\xb6{\xf1\x85'
        b'i\xe9#*\xce\xaa\x13\xc52\xe9\xa7P<~W\xf5*\xee\xd2\x08,d}\x8au4\x1aq\xb7\x86\xed%+\x16\xf3<\xe6v\xf6\xf5`\xec\xba\xe1\xc0\xd9\xab\xd8\xc9\x10\x13\xb5\xa5bG\xd4V\ns\x7f\xf8R\x01\xef'
        b'`\x8c\xe7\xc2\xe6y!bW\xde\xa1\xfes\'"\n_\xe6\xeae\xf0\xa97\x15b}\x90:lFK$\xa5\xe84\xcf\x9a\xf4\x0e\x9b\xfcD\xa1l\xfa\xf0\x07\xfd\xf4\x07\xd8\x0f\xec\xcb\xfep\xea\xcbB\xcf\xe2G\t\xe6'
        b"n\xd3t\xd3\xabr)\xcc6\x95\x1fM\xa07)\x08\xf1\xf1\xe3\xce\x9c\xbc`\xb6\xeb\x19\x0c\xe8\x14\xe1\xcd\xd0\xf6mx\xd0\xa468W#\xd7\n\xd5\xa1\xdd|\xfb7D'6}\xb0\x8a\x90\xb3\x07\xe4>\xbe*E)"
        b"C:\xaf\x9f\xc2\x19\xe8\x91]\xa55g7\x87x`\x1a\xa1'k\x11\xefx\xf1\xa9\xceT\xd7\xb7NU\xb1L\xa9\xd0I\xd1(\xe7\xda\x93?\x8b\xc2\x8b\xb0c\x91FL\xba\xca\xbc\xd9\xb0]{\xc7\x90\xb4\xd3\x1f\x8ag"
        b'\x13\xc6\x82.\xcd\x04\xcfs\x11\x1a\x89\xb7q\x8c\xe9\x98\xbf\x07\x1c\xf9\t\xad\xb1R\xb5\x18\x92\xa0\x1f4\xc7\xa0\xfa\xb7?\x8a\x17\xbd\xf0\xee-\xff\xb5\xb8\x07\xd4\tl\x1a\x1a\xf8\xfcza\x93d\xb0\xe85\xb71\xdaZ\x88'
        b'\xd9\xd3\x88ci\xa0\xadL\xe0\xa7\x93a\xb7\x81\xf7\x98\x9fng\xca\x80\xaf\xe4%\x8b\x02}Vn\x9c\x0c\xa3\xb68\xda\x80\xa6\x9b\xd5}\x87\x0c\xd5\xea\t\xaeGCCX\xd5\xce*\x15\xd1Er\xc9\xff\xbf5"\x96"'
        b'9\xb4\x94\x02kJm\xf8\x8aTo@)\xffp\xa3\xa7\xaf\x98\x1d\x97\xfd\xa0{\xea\xb5\x94x\xe6y>\x93\xd6\xa7i\xb6\t\xd9\xbay\xee\xb9\xd4\x88\x82\xba%\x8d\xa7\x93a\x94\xdc\x8b\xe2*\xa9\x98\xefv\x85\xfb\x9f\xa2'
        b'\r}7\x14\xa2P\xa8\x99\xe3\xba\xe1\xbe C\xb7\xfa\x92\xda\x86;\x82\xec2\xac\x1f\xbd}{59i\xb1\xb1\xfaE/h!CK\t\x15u9\xa29\xd9\xb5\xbdd\xfb\x02\xc2DK\xe6\x89.8\xf89\xc6\xdc\xea'
        b':\xa6\xbd$\xbb\xaaQV\x87)hC\x83\xf4\xa5\xe8V\xb1\x17\x05\xf8I\x9ezC\tH\x97\x97|Z\x7f\xbe\xff\x84\x07?\x85\x84\xa8\xd4#\xe1\t\xff\xc2\xd0\xcfZ\xefr\x00\x1b\xe9\x82\x0b\x80e\xcc\xb3\xc4C\xc3\x96'
        b'\xe8LT\x84\xa3*\x10\xfd\x95\x8cv\xf0ZP\xa7\x90~\xb2\xe6\xa1\x08L\xeb\x05n\xacOk\xcf\xd4\xfc\xff \xc0\xe1\x04=\xec_\xf7\xb0\xe1\x16\x88^\x11[\xdb\xea3\x0c\xa3T\x10rh\xc7\xa9\x05\xd5l\xcd\xa7\xaf'
        b'Q\xa68\xf2\xbbvxT\xd7\xed./\x0b\xad\xa3\x9b6>8\x12\t\xa1BN\xf5\xa3\x98v\xe5\xe8I\x19`\xac\x06}|\xa6\x14\xbd\xb5\x8d\xffz\xc9\xdb\x10\xd2\x92?h\x05\xc9,\xb3\x8eX\xb7R\x00\x9e\xf2\xfb\x1c'
        b'<\x82\xa1q|\\$\x8e\xe8\xe2\xd9&\xac\xe1\xd4\xe7\xf0(\x14E\xfaci1:\xa9\xf1\xe6\xb5$=g\x93\xfd\xf7\xe4\xd5\xbe\x9e#\xdd\x9a\x0b6\x0e\xc1R\x93I\xa24I0\xe2\xf8\x0erl\x1a\xa7\x97\xf0\x8d`'
        b'{6B\x07\xee\xdfuX^S\x14r3\xdd\xa1%%\x86\xd3Z\xfd\xd4\x08z2\xe2F\xac\xcf\xb5\xed% 1 KWT.\xca\xad\xd8\xfa]\xf1\xe4+\x08e\xf7\xe0\xbcp\x91\xb2\x17\x1a\n\x17x\xf4\x1a@s'
        b'O\x99K\x903}\xd3k\xf73\x90\x0f-\x14\xe6\xcfg\x94\xba#\x1c\xe5l\xb1%F\xc6R\xb5\x1f\xb9\xe2\xb0^.\xdd\x0e\x8b\xe3\xff<\xca\x1eF\xb9\xa9\xad\x9f\x8c^b\x91\xa7\xc8\xb5@+\xed9\x9d\xc9\xb5\xc7g'
        b'c\xcf]\x94\xa6\x01m\x0e\x94\xde\xa3:%\xf4\xe9c4l\xd6\xf5\xd9\x97> \xdb\xa0j\tU\xddx9\xbd\x1f\x8a\xc5\xae\xf7a\xe4DZh\xc6\xa7\x16\xbf/\xaa\xb3;\x80\xe6i\x16\xa5\x96\x84cr\xd9"\x98\\'
        b'\xbbU\x97\x17\xe7\x93\xdc\xc6b\xb5\x83\xa5"\xf8IlZ\xf5\xdfnC8\xd2\xbf\xeb`\xaf\x11$\xd3\xa7*\xceo>\xa74`\xc2\xa9\xe9\x19/^\xd5\xd0t\xa57\xf8\x19\x0e[\xa9\x1f\x02\xb2\x88P\x98;\xbc\xea\x0e'
        b'(8\xebVo/5u\x8e\x8c\xe4\xaePf\x18\xc3L=\xa5j\xe1\xc56\xc7\x91\x8aI@*\xcd\r\x95\xd1\r2\xa1\x98\xad6_\xe5{\x0c\x988\xda\xae\x00{\xa1\xae\x9eW\x1e\x90\x05\xe5\xf8\x9b\xa2\\\x18\x80U'
        b'\xf8\xce\x831\xa7a\x9e\xf4\xd6BV\xf6G?\xdf\xe1\n\xf6\x05\xb9\xb6m$\xbc5\xe6\xec\x8al\xf3\x9a\xeeXV\x1a\xd6\xcb\xeb\xa8\x16\x11\x86\x9c\x8c\xbd\xd2\xed\x10\\\x12\xafH\xd6\xbe\xe0\xc6\x17,Ih;A\xf7\x12'
        b'V\x8e\xeep\xc0\x0e\xa4\xbal\xfcy\xa1\x90\x84f\x94\x0c\xf1\x03\xd2\x01Sr\xd1\xc4\xa5=x\xc1\xa5c\xc9\xec\xcb\x84?\x0c\x9f\xf0pH\x19g\xe8|\xec\xaaU\x97\xa9\x12\x96|\xc0\xed\x10P\xb3\xc8\n\x1e\x07\xc3>'
        b'\xe7\xd9\xe3\xe8\xeeD\x19\x9f\x8bz\x84\xb4\x1c\x1c\x94ur\x9b3\x0b\x97!~\xca\xd7\x0b@\x03D\xccn\xfe\xb0c(\xadwoTE\xad\xc2ZRr\xdf\xc8$A(\xb3\xf6\x0eQadR\xb8\xacI\xbb\x17H\x8c'
        b'\xf3o\xca5\xf2\xad\xb8r\xd4\x84msAg\xc9o_\x80\xf8\x12\xeb\xca\x16\x96\xc3$\xb4O\xbb\xcaBo\x1d\x07s\xa7\xc5I\xdc\xa4_\xe5\xc6\xb1H\xa8\xb3\xaf\x7f\xdb\xf2Lt$\nM\xb815}I\xdbW\xf0'
        b"D=\x9ak6\x93\xcc\xde\xa9\xdc\x06O\x1e$\xd7G\xc0\x12w|6Czp\xae\x95>k\x90\xc3\xb9\xb6\xe2\x85\x0e?\xca\xad/\x19\xf1\xe2&'\xd8|\x99'|\x18\xe2\xe8\xeb\xc4\xd3\x7f\x0cG\xb3\xe4p\xf2(\x8a"
        b'\x9a:\xcc\x93\xfc\xe8\xab\xf3\xc8\xaf\x10\x96\xb5\xe0N\x8b\xb4\x1e\x0cU\xd6JHy\x0e\xc0\xda\xaa\x1ed/\x91\xd0N\x08\xf9A\x0e9\xbd\x16\xef\x10\xc6\r\x8eq\x0f\x88\x85\x8c\xb8\x08U\x9b\x7f-\x1b\xbc%\xbf\xff@\x1e'
        b'\x81\xcd-p\xack\x96)*\xf2\xb0\x01}\x9e\xce5){v\xab6g\xa7\xac!\xcd\xa79\xe4\xc6>\xeb\x92\xaew\x89&@H\xc9\xfe\n\xc7\x8f\x11+\x05\x08V>S\xfa_\xfdA7\xa0U\x8d\xda\xaa?\xaa\xa3'
        b'\x053\xff\xfbl\xd2\x85z\x94\xd8\xa1\x8d\x8d\xb6@\xd7\x88\x18\x88\xc5P\x14\xc5\x9d;>>v\xc8g\xecD\x0e\x8b\x0e^y\xa2\x87_\xe2Gv\x855\x84\xdd\xe5W\xcd\xb7\x15\xdf&\xce\x18\x7f\xe4\x8a\x94\xec\xb0-\xdd'
        b'\xef\xe4g\xd0*xKFi\xb6\x19* \xde\xa5\r\x1c\x85\xf2:\xc4\x93\xc9\xac\xb4\xd9"\xea\x05:\xcd\xa9n;E\xe9*\x83\xf3y\x9b8\x919-\x06\xd8\xd2#\x10\x17\xda\xec\x95W\xfb\xf2r\xef~\xe1?\xd5\xde'
        b'n\xb4VMv\xe4\xe3\xd7\x1aXj\xac\x97\x9d\xd5{\xb8Z\x8a\xfaB\xf3t!\x90\x10\x0c\xd4\xe4\xc17\x7f\x97O\xca\xe4\x82\xb3\xb42\xe9\xc9w\xafu\xf1\xb2x\xa24x\xc6\x8a\xba\xaeg6\x8c,\x97C\xfbeK'
        b'\x8d\x82\xd1A\xe8\xd3\xf1\xbf\xa2\xda*\xb95\xb8\x08\xe4\xc0\x87\xfb1\xf6\xecrB,^\xe4,\x12\x8a8\xc8\xda\xdahW\x17]R\xed]\xfer\xe5\x01\xd4Y\x03\xcb[\xd2\x9b\xf5\x8d\xa4<^1\xc2\x94\x89\xdc\xe7X'
        b'\xa7\xe0\x88\x01L\xf7\x87\xe9^X>pwH\x1e\xf7(>\xa9\xf4\x0f\x15\xf5\xe1\x03\xe2+\xd7D\xd47\xd7\x84\xc8\xac\x8cL\xae\xcf\xf0\xaf\x1fE3OBX\xe5\x16Wm\xaa\xc1\xc9Q\x0c\xd2\xd4v7\t\xf7\xca\x8f'
        b'!u@f2"\x8b\xe8\x95g\xd9\xf6?W\xe4\xfb\xf1\xcdF\xb3\xd1;\xe3/\xe1]\xcdj\xef\x99\x1f:>n\xd4\xb7\xbb\xc5A\xd2Z=\xad\x97\x9e\xdf\xa3N\xb6\x0fN\xcbN\x91\xdf\x9aZ\xb40{g\xbaa\x1e'
        b"A3)\x93\xecm\x95\x8e\xa1Q&\xb6\xe1\x1e\x98\xadHbh\x83\xfd\xc8;b3l\x95\xb8\xa7\x98';\xc9\x7fM\xaa\xd9\xd4\xc8\xa5\xcb\r\xff\xab\xc3\x03\xb7\x0f\xa5\xd9\x85\xb4\xafW\xae\x8f*\xc6s\x97\xe9N\xb7\xbf"
        b"\xc7\xa8\x8b*\xd83\xf1\xda\xf70'\xc8\x16\xfc\x99\xb0\x98\xdb\x08\xe78\xad\xb5\xbb\xfe\x9dUJ\x18D\xbf\xcf\xfe\xd6\xa1\r\xe8<k\xba@\xf7\x93\\\xad\xd3\xd7\xf3~>\x1a\x1c\x88\xff\x9d\xf9\x15Wx\xf7\xeb\xbd\xed\x1b"
        b'\x11\xeb"\xe8\xcb\x07\xc5\xc95\xf4\xf8\x1a\x12!\x97\xff\x93\xfcH\xe3K\xc2\x97(\x8dPsA\xa6\x06%\x15G,0\xa7\xd3#\xe3\x97\x84\'[6\xde\x87\xcf\r\xad\xf6B^4\xc8\xb1\xf9\xa3\x17\roj\xc0=\xd5'
        b'\x14\x03R\x88\xc6-\xe0d*\xbe\xec\xb2D\xe5seI{>{\x94\x8c\x929:\xec$\xcdm\xda\xb7\xdd\xfc\xf0I.\xd5\xfbF\xa8\x0bN\xef\xe0\xdf\x97a]\x188{\xc6\xad\xd3W\x05\xc5z\x98\xc9V!\x1f\x99'
        b"\xecR&.1\xb6k\x16\xc1N\x03,\xd7\x95I.z0T\xb2G~\xd5\x86\xa6\xb6\xa3\x8b\x05b\x9b\x94s\xb0\x10\x9en<\x90\x9b,\xf4C\xb9'\xbf\x8e\xed\xbcGb%\xc7\x955\xba\xa5\x03L4\xe6\x9f\x99\x89"
        b'\xf6*:N\xe8\x8b\xf4\xbd@\xa6\xbb(G\x15\xc6\xd2\xb4\xad\xb2F_\xa6\xfa4\x02\xa1\xbe\x10\x80"((p\'~N\xfa\x99\xc4\x1a\xb5\xee\x05\xe5.\xb0\xcf\x19g\x14\xa6\xdfX\xf4\x06\x80\xe6 \xa3&\xe2\x1eA\xa8'
        b'\xa3\xd5\xa8\xfd\xd6\xcf\xde\x95\x91\x87?\x821\xd5\x85\xc9\x9bal\xb3\xef\xff\xd5=2\x06\x8cAh\x1b|\xb7(\x8a\xc3\xd6\xc1\xa5?\x8c\xec\x93j\xef\x96H\x9cu\x81\xb3\x00\x81h\xbf\xd3s\x9d\xa7\xc6\xd3\xf8m\xc7\x1b'
        b'\n6\xceK\x83\xbdQ\xb5\xc8U4O\xfer\xcc\xdc[\x10\xc1\xc2\x13\r\x1d\xfag)\xa1\x8f\rf\xbfU\x06]\xf31\xe0hy\xa2h\xdc`\xe8\xffx\xf4\xb4\xd0\xa4\x96\xef\x9d\xd3\xfa\xcc\x11\xe6~\xb3\xfb\xcc\xaf\x96'
        b'\x00:|5\x80\xcf\xaf\xe5\x93\x88\xff\xd4\x8d\xc5/x\xa4\xdf\x1e\x91\x8d\x8bg\x85w0]\xba\x82\xf1\x8a\xe9\xf6\xc3\x89\xce\xde\xe2#\xd9&\xa1X\x96?\x9dF^\xe7m\xb2\xd4\x1f\\\xad\xe8\xba\xe9\x85?\xcf,/~'
        b'\xdf,|\x8c_\x8b\xcfXe#\xefn\xd6C\xa6\x98\xf6\x8c\xdf\x00q,\xe3\x9e\x10n\x03\x9b\xe6\xa4Av\xa4\x1e\xcd\x13\x91\xcb\x08\xdf39I\x1c\xfc\xe9\x0e\\\xaaJ\x05\xd4<^\xe8\xa2X\x80\x19\x18\xe0B\x88\xc7'
        b"f6\x99\xb6\xabW\x9e\xc8\x12p2\xbe\x97!\xc0l\xca\x0e\xe0\xfd\xdb\x1e&\x11\x87\xda\x0b\xab\xfeZ9\xd5^?\xd1\xcfP\x86\xe1\x91\xbe$\x1eZ25\xa62\xc5\xd6IDZ\xc4\xd5C'\xd9\x92Wy\x80\xad\xf2"
        b'\xf2fg\xa3L\xac\xaa.v2\xea\x88.eI\x9f\xb6\xf7\x9b\x1a\xea6\xd1\xc1\xc9I\xe6\xce{\x1ct\x0f\xff=\x8d\x08\x1a\xbd\xffU\xe8\x1d\x0b\xd7\xcb\x1c\xaf\x11@z\xd5\x19\xa1\x95\x97\x80i\x06\xeeEG\xa4,\x01'
        b"\x07T\xc9\xd6\x85\x90\x1e\xb3\x15Y\x86\x02\x84\xcc\x82\xcd\xd5\t\xb46\xb4\x87MT\xaf\xc0\xe2\xa0l@\xf4\xfbj\xf2AZ\x12\xa7\x1d\xe3\x0b.\x81\x1f\xbe\x00RB\xc9\xc0\xd8'!\x9a\xfcu\xc0\xbb\xf7\xe4G\xa0\xc2\x97"
        b"\xca\xf5a\xb4\xdd\x14\xe1$G\x1e\xc7\xb7\x081\xf2\x98\xcc\x07\x91\x149q\xc7'\x8e\x8a\xb2\x16\xack\x1d\x88j\xaf#\xa1\x8bj$'fW\x18\xa3WL\xdc\xae\xa21K%\xcd\xa8\x8d\xd9%\xc7\xd8\xa3d\xec\xf7C"
        b"\x08\xe9\xb5Y\xdb\x82\xb1\xc8\xff\x8d\x88E\x1dx\xad\xe9tg\x00\x86}\xea\xa7\x19=>\xeePS\xe5\x1a6vG\xcc\xa6\xd4\xa3\x9b\xb0\x9d\xb1o\x9f\xea\x1c<'\xe8\xa3\xc9\xed\xb3\x80B\xee\x9d\xae\xb7\xd9i)\xc2~"
        b'e\xae\x9b\xf6\xaa\xc1\xd8\xfd\x89\xb2\xcd\x12G^\xb5\xa3\xdd\x8a\xb7\x82=YvI2\x92k\\\x14\xf5\x154\x05+\xbf\x8c\xa6%\xe2\xd1\x87\rO\xfa\x1c\x97u\xd3\x1d1\x84\xb5]@\x08\xb1\xa4\x1d\xd1\xfds\xdf\xc4\x80'
        b'\xa6\x9b\nOi\x85\xcb\x81c\xd22\x10\xd6@r\x89D\xc5\xef\x8f\xf0\x8b\x99-\xb1\x1c\xf0\nAd7\xd4 \xbb\xe0M\x81X\xd4PA_\t\x11\xe1\x0b\x8c\xe5\xfe\xbc\x01\xaf\t\xbd\xa1\x8e\xf5j);r\xc36p'
        b'\xdb\xfe\x15\xaa\xce\xddB^#\x1e\x9c7P\x8d\xd3T\x12\xee\xb0\xd5F\xde\xbe\xe7\xc1AB\xf7\x8f\x89\xa3\xed\xd8\xaf\xab\x9d\x85\x1b{\xee\xa1w\x8dPB\x06\xb4\xf0\xf2\xb2\xdd\x13\xd4\x998\xfe*\x0eM\x16ti\x92\x18'
        b'\xa9\xd1\x83\x840t\xbbz\xca]\xfemm%\xf8$\xee|\x14\xba>\x97\xdf(\xb5\x8e\xa2\xda\xbe1\xa4\xcc\x12\xf9\nc\x1a\x06\x8f}\xd6\xbf\x7f:*\x85\xebhk\xac\xaf\xdf\x9b\x89xz\xc1z-\x90\x1dN\xd8J'
        b"K\xc7h\xd3\x86%i\x03\xac\x93\x90\xd1\xbc-S6\xd5'\xfb!\x08\x1dt\xb6Ze\x88\x11\xd4\xe6\xb5@\x11\xdf\x0b\x9e\x12\x969\x86d\x12\xf3i\x8b\xd1\xcf-\x15\xf9w\xe2v\xef<p\x8bwS\xd7\x96$\x1b\xf4"
        b'\x80P\xcc\x0f8\x19\xdb\xeb\x03{!\x83O\xef\x90\x15\xb9M\x9fD\x0fP\xa4\x19\xac\xe1\x92\xad4\x93\xe5|\xa4\x07\xac\xd2\x00\x9aE\x91\xe0\x99\xaf7CU\x19_e\xcf\xe6\xf6Z\x17.O\x96\xd2\x1e\x1a\x80\xcb\xa3S'
        b'\xfd\xf0E\x9d\xa6Y\x82\x90r\x05\xd0D\x1d\xd8m\xb4\xda\xdc\xf1\xeb;\xb7\xe0)\x9b\xebV\x94\x06\x18-a)1\xb4\xb5\xba\x9d0\xc3\xd6\xd88@i\x13s\x0b\x1d\x8eS\xaa\xb7]v\xff\xfb?nzA\x81\xa0F'
        b'\x8a\x92[\xe1\xbb\xf5/\xba\xb6\xc5\xfe\x14\x12m\xcb,\xbf\xf3\\5us \xc4\xdd*(\xab\x07\xfe@Ek\xa6\x9e\xf0\xfc\x8e\x10\xe6`y\xc2\xc9b\x111\xc2\r\xe0\x90\xa9\x0f\x83\x97\xb6\xf5\xf6C/\x1c\x83\x82w'
        b'#\x97\x15\xb5e\xd1n)\xd4\xcfmNVbEn\x03d\x0e{\x19\x8b\x8f\x1b\xd1\xb5.\xfeU\xf2&\x91T\'qc\x96~\xf1L*8\xfc\x17r\x9a\xbd\x1c=\x13Y\xc4F"~\x10Vaq\x04s\x06\x13q'
        b'tfG\xa9J\x05\x8fN7\xbf\xfcL9\xcc\t\xebP\xf6\xf6~jd4b\xdf\\#\xae\x1b\x88\x1f\xfb\xfb\xc0\x80\xbe8\xbb4|\xfa\x92\xc1_\xab\xba\xd0\x84\x87\xb6\xe5\xe9\xfa \xa0\xbc\x83L\x96t\x88p3\xe6'
        b'I\xa8&6x\xf3\xb3%\xfe)\xc5\xa6z\xa76l\xa5~\x95\x04sbV\x9ceI\x98G\xf9\x1b\xb7\x0c\xdb\xf2\xc2\xff\xa7\x1b^\xf0|?\xadX\xd6b\xfb\xcc@\x94!)\xde\xe4l\xf6\xad\x85\x890f\xe9#\x1f'
        b'|\xaa\x0e\xdb,\xb7RrD.\xea\xa7w\xa0\xd5_uI\xb6\xe7Y!\x85\xff\x8e\xa1\xb4wM\xa5\xb8\x07p\x9d\xbb\x155\xf1\xeb4\xc2P2\x8c\x98\x12\x04\xe9\xbe\x0b\xf1\x01\xfafL^?\xb7\x9c\xf7\xbeO\xcd\xc5'
        b'X\xd4\xda9HhBa\xa1}\xca[\xd4&\xc6\xe6\x1a\x96\xb9\xe99hI\xe1\x9e\xb3V\x0b\x8a\xb3yW\x95\xad?\xc0\xb7\xa5!]\xce\xc2\x02\xe8\xb5\xbdxn\xd2A<"\xae\xb1X\x96Xl"o\x88\xc2\x80L'
        b'b\x0c\x96\xc2.t\xa0\x88\x8c;\xeej\x1e\xa5\xed2Q\xbdU\xa8\xc8\xfeLg\x19\xe9\xc7\x0f\\\xe5\x9a\x0e\x12\xa1D\x05\xe3\xe7\x9eK\xcav\xdbc\x8d\xcb#\xe6H *\xdc\xcb\xae\xeb\xf4\xd9\xf4\xe0\x9a\xaaF\r\x8d'
        b'\x14\x80M\x91\x8a\xb1\x06+\xed\xae\xa5\xe7?\xfd\x93\x81h\x08 \x9d\xe6\xff\xbb\x08\xf0s\xa0\x9e\xb0.G\xea\x1f/\x08\xb6\xdb\xf9\x8e\x08\xd5\x8cu[b\x02\xc0\xe3\x97\x02\x8a<\xc2\xfac\xb8\x01{.\xe7\xfc\x04\x1f\xb2'
        b'\x14:"0\xfc\xe6\xf0\xc3\xd6\xabk\xd8\xb0\x99Sr\x19\x94 \x7f\xc9\xe1\xfe\xba\n\x8e\x93G\xf3\xc5\x07\xa2>\xff\xac|\xb4\xf6\xfd\xf6\x03 \xae\x87\xaf\xdc\xea|\xab R\x08\xe4\xe4\rM\xfc\xf7\xe8\x11\x97a#N'
        b'\xb5<;\x80>J]\xc3\xb1e\xb1\x9evP\xf0\xf2|\x9c\xe1\xf9\x93$)\xca\x1c\xb3\xccZO\xb0w\x14\xbcG\xfa\xdf\xf2is\xf4\xf9\x94\xb9f-(\xa8\x14d\xa1nMz\x90r4\xb0DO\xc0\x8c\x0bV\xe8'
        b'\xb7G\xf1\x87\xa9\x01\t\x9b\x8d#QC\x00\x0e\xc7`V\xa68\n\xfa#H!P\xae\x04wNM\xcc\xd1\x91vx:\xafK&O\xa7J\x96\xb6y\xd4\xfd\xc8\xe1\n\xeb\x9e\xa2}\x177dzjF\xe9\xf0\xe9\xc4'
        b'\xc6\xb7\xc3<\xc7\x8b;p\x91+9R\x1d\xc3\x0b\xabO\xe6\xf5\x1d\x99\x08\xfd\x8ea\xba-\xd4i\x99\xc4QS\x01\x08\x8e\x8c\x8d\x90\xf3\xbb\xf2\xd17z\xb8\xa34 \x0e,\xd8"\xc2\xb9\x8d\x9e\x8d;\x1b\xef\xed\x813'
        b'\xf7\xeb\x08\xb1\x93\xf7z\xf0\x15\xcb\xd5Wj\xae\xe1\xd2$\xfetkq\xc1UC\x0f\xf4s\xc6\x1f\xb0\x01\xda\xb0@b\x13\xf6\xf0\xf7]\xda\x95\x14o\x98\xf8H\xf6np\xdb\xe6m\xc2\xe6U\x08X\xd5\x8dW\xbar\xd2'
        b'\xaaR\xa8\x1f_\xd8Dr\xae\xc5S\x1dv\xa4\xc0\x043nk\xfc\xe0\x94\xda\x88\xc6z\xc0\x0b$\x8d\xebN_\xd9\x81j\xae\xd0\x1f2\xa1vC"\xbe\xd9|\xa2"\x11\x80<\xcf\x03\xd5A\x16\x9c\xe48\x9b\xbc\xbc\x10'
        b"\xf3~^N\xe5g\x95`\xfa\xc4\xaf_QD[)N\x14H\xce\x01'\xcbO\x1d\x05\xdc\x7f\x8d\x9eH\xae7\xd3U\x91t.\\\x9d\xfb$\xa6\xf3PS\xea\x8b@\xa8\x9a\xc0^\x17\xd3\xc0\xdf\xa3\xff\x13\xa3A)\xd0"
        b'e\x1dO\x99\xe8\xf6rX\x9dc\xaaT\xe9?\xb7\xd7\xd4\x99\xc9\x08\xf9\xdbL\xa4\x97\xf2F\x03p\xe5\x9e\x03\xf1\x06\xa7v\xc6\xb1)-\xd9#\xd3\x04\x98\x06\x10X1>\x96y\x8e\xd1\x87,\x80x\r\x95ZB\xf7J'
        b'\x1c\xbfqr \x8e\x11\x93\x93\xa3\xdd\xf1n\xd9\x13Wn\xcd\x15U\xb0\x1e~\x9dUK\x12\xdf\x11,\xe6\x0b\x04q\x996\xbd\x90Uv\xac5\x9f\xde\xc6\x99\xaa\xf7\xb0\xff\x00\xcc!\xe16\xda\xecx\xb2\xb3\xa0\xcf,\x8c'
        b'w\xc1DP!\xff\xf7\x9d\xed\x92\x1c\xa5\xadM\xfe\xb2\x94LbX\xacz\xef\xdf\x85\xd8^\x97\xb9=F?\x8c\xcf\x9e.3x\xa1%\xf2\x93\x1e\xc9\x01\xa0\x0bX\xb81\x93\x14P\x86\xcdt\xd2\x11\x13Ky\xc5\x17\x83'
        b"+\xa54'\xd1Kh\x05\xdc\x08\xc2\xea\x99x:k[\xf8\xe866z\x8c\xdc\x94\x13\x10\x85\xf5\x8c\x12\xbb\xf60\xb5\xeb\xb5\xf8\xb8\xef\xfb\x8e$\xc1\x02i\x02s\xde\xee\xf6\xac\x04`\x02\x87?\x9b\xa2\xaf\x07;C\x02"
        b"\xc2\xc7\x1e'<\x92\xad\xb7YEB\x8a\xb9GL\xad\xb2\xbd\xe4\x8fB^v=\\\xbc\x17\xf4\x8c\xe8,\xc5&\xa6\xab\x0b\x87\xe2\x08\xbdS\n\x80h\x0f\x1d'+\xf9\x8c\xc1\x89S\xb1rQ\xb4\x17\x99<\xb9\x06\xd0\xc0"
        b'4\xbb\x9eTy\xe3\x1eY\x9b\x05\xaf\xc4\xff\xbe7$\xce7S\xf1\xd0YM\x86\x98\xba\xad,\xd0i,\x98\xf1\xac\x08\xc0t7\x16\xab\x15\t\xf5\x0by\xae/\xd5\x14\x83\x86\xddDr\x83\xf9\xe6\xcc\x00\x1eH6@\xa9'
        b"B\x16\xf1\xa24\xbfm\x1b'\xb0\xa2\xb6>{p\xd3jG\x7f\xe9\xe6\xb5N\xea\xed\xb3\x83o\x96K\xf3\xf7|\xb7\x1d\x9d\x03\xb0\x88\xd6\xb81\xd2\xd8\xe2I\x90;3\xcey`\x02c\x1dB_\xb2\x9d#:XZ\x94"
        b'\xb6o-\xf8\xde<\x9dMBH`{\x8e\xd9\x82\xe5\x95\x1aHG\x13\x83\xcf\xf5\xe2\x07\x06`\x94\x9f\x80\xfb]\x95\xe72\xed\x14p\x0flUC\x9c?\xe2^Dm\xee\xf4v\xdfq\x85\xa6Pi\xcb\xa03\r\x0f\x98'
        b'Hs\xc3IqV\xb0\xe1%\xc9\xed}\xeaNA-o[&\xad)\xbd\xa0\xacg\x88\x0c\xe1\xb9A\x91\xa82`\x15_X\x82\x98_a\xa6\xf4\x03\xb3\x0c\x8a 8\xf7)\xfc\x9fk7c1\xbe\xfc\xfedu\xa2\xbb'
        b'v\xafK\xd2\xec\xbe\xeb\xc0o\x17\xa9\xa6]\xc3\xcb\xba\xbb\xd8=\xc8mgQlT\x89\x86\xb0\xa5I&\x0c\xdd\xd47\xb3\x87\xa1/@]Q7\x7f\x1c\x8a\xf5\xe3F\x90\xa1\x9d\xe4\xf6\xa7 S\xb6\xd0q\xa6\xb2\xf2k'
        b'z;\xdd\x03\xfc\xe0\xa4\xe7:\xb3\xe6aX\x86\xd5I\x8f\xf9\xb4\xeb\xa0\x80+Z\xe5\rs\xa0\xefLC\xf6\x15\xdf\x8anD\x80\rd\x9b\x83\xa3\x17I\\ /\x19\x9b\x07/\xa2q$\xee\xa7\x04,z\t\xf9\xc1\xb3'
        b'\t\x0c4QX\x8c\x92\x03\\\x13r\x19\x82\x86\xccOn\xbdAf\x02\x83\xf6f8\x88\x9e\x0f\xb1\x9d\x15\xce\x10us"\x15A%\x80\x1dB\xf1\x03X\x16Tt\x81/\xd0Jl\xdf\xc2)\xd1?s\xd54C\x01\xf7'
        b'\xee\xbf]\x15\xc1t\xe9Z\xc1\x90K\x00\xe6\xa8\xce_\x8c\x86"$\xc8\xdexIt\\\xaa\xb1(\xab1G[8\xab\x08A\xc1\xa5\xa7\xa5\xe8\x06\xa7\xbe\xfaM\xa3\xa5\xf7\xd6\xf5p\x8ea\xb1R{\xc7-*:\n\xf9'
        b'\x1a\xc0.\x03\x16\xc5\xbb\x9c)RZs\x07\xe0I\xa1\x9bO\x04\xc0\xe80\xe0\xd5\xeb\xf5\xfahU~bB\xb4to\xe0\x9c6\x9c\xfc9\xf4:K\x03\x14\x15\x89\xae,g\xee\x92z\xc5\xd3\x1c%\xed\xfe\x93\x8d\x81\xda'
        b"\x98\xa2\x125\x8b\x89\xf2\xcb\xc2\xfb;\xb2\x90\x8eN\xd7BK\xa5\xab\xb3Wd\x0bs\xf8Z\xf8\x8d\x06U\xc1^'\xa4\x94\x0f\xdfd^\x1e;\xe9_\ra\x1f\xec\xca\x85\x07\xff\x86\x9bMd\xca\x0e\xe2Tj\xddaX"
        b'L\xc4\xeci\xa2\xaa\xb7?m\xbb\x0e\xab\xd3\xa2\xb7w\x9d\x9d\xcf\x9d<\x99\x1c\xf7\x1b\xa3FBQ\xa8U\xee<*K\xd3?\xae\xbe\xfb\xaf \xee\xde\x0b\r\xccTg\xb7\xa4\x11x\x1b\x9c{J\x9b{\x83\xb7xw\xd5'
        b'\x14\xe2lN\x1d\x14\x1a\xea\x06\xa5s-\xfa\xbc#\x84!\x9c\xce|X\xfb\ty\x94\x80_\x13\xe1\xfb\xee\xb3n\xf7\x0fa\xe5@7\xbd\x11\xf9S\x19k\x01\xa2\xb87\xb0\xf2\xb5\xcb\xd4%\xcb{\x8by\xbbKmbV'
        b"N\x90Wf$T\x046!f\\F#@{\x1cO):\x96\xe9\x16\xba'T\xd6Y\x90\xa7\xcc\xe3\xf2v8}wI\xc0\xeb7\xc4\x82\xfe\x15\x9fsB\x1f7\x84\x1aXn\x99\x1cVU\xde$\xb53\x07v\t"
        b'\xc5\xbb\xfc\xb3v\xb9\x8d\x18&\x19\x104v*\xef\xf1\xea\r;\x8fI\xf2o\x1a\xe6\xc2\xdd5\t\xf7\x91\xdfBD\xb0\xcb\xf0\x1c\xd1\xa0Z\xf2z\xc1\x02\xa7|\xd1\xa6><\x91\x19\x8bT\xd8\xf6)\x83\xbe2\x88v\xcc'
        b'\xd6B\xd2\xdc\xe6zY\x19\xdaA4\xddm*\x03\xf2\xd0\xbbV\xacz4`\xecZ\xd3\xe0{\x93\x83F\xb6\xe2\x85\xf6\xdb\x04\x02a\x93\xa4\xe2\x14#\xd7\xaa\xc6\xa7\xe7)\x81\x94\x0b\x13\x01ND\x10\x95\xbep\xfd\r\xe9'
        b'\xe4P#\x84C\x16\x94Y\x0eYi\xa8\xdb\x1a\xf59\x84\x8c6&D\x8fJn\xdef\xb3\xe4m\x05\xc0\xa6B\xb3\x80)(\x9a\x8b\xeb\xd4g\x8d.\xa6s\xa54\x0c\x15\x164[\xeb[\x12/\xc8\x06zVI2\x12'
        b"\xe5\xa35:\x1f\xd9\xf3\xb5k\xcd4s-\x19\xb7\xdc'\x0b\xe9\x81\xa6\xa1\xa3a\x9e\xca\x91^X\xda\x94S6\xca\xc5o\x9c|I\xd1\x98W\x0c\x8e\x8f5O$m\x03\x82\xcd\xea\xe70KR\x17\xe7\x80\xa0\x8e\xcag"
        b'\x1c@\xa9\x98\xf8\x97S1{\xb5\x02\xdb\x9c(\xcb\x89\x90 \x9e\x10\xff\x98\xf20\xc3\xdf\x13%P\xe9\xa2\x15`\x7f\xcb\xf7u9a\x97\xb8\x82\x94\xfc\xdd8\xf2\xaev\x00\x90\xfa\xf9K\xfe\xd6wGGD\xc9\xbe\xcf\xed'
        b'ow\xb4\x98\xfft\x92\x8d\xb3\xd9\xa4\xbcw\xda\x8b&g\xa8\x11\xf2QT\xb7\xc7\x82\x85\x7f\x1c\x07`\xc3v6.8\xfe\xcb\xa9\xe8s\xdd%"\xd8\x08\x01\xf0\x92.v\xa6\x0eN~\xa1m\xd5\x96\xdc\xfa(\x8f\xf2\xfd'
        b"\xb6\xa1\x1f8\x0c\t\x7f\xe1\x86\x1b\xe9\xc5G\xd7\xa4b\xb8\xd9\x92\x1c\xd1\xee\x0bq\xf31\xd6\xdfZ{%Q\xe5\x1a_v\xd43\x18\x95S\x1a9R\x89\x05\x9bZ\x94)Uj\x19f\xf8\xe6n\x80\x9a\xdf\x19\xf7'\xdb"
        b'nac\xd0Mt\x7f\xe2\xf0-I"\n\xd2n\x8f\x98\xf9J\x91%4$+\xd7 \xc4\xba\xc1\x9d\x14X2m!\xe1\xef\xaeo\xe7\x1d\x81\xbd4\xe1\xc8\r\xa2A\x0b\xf9*\xc9\xbe\xe5\xab\xa6\xf4\xc6=\x87D/1'
        b'\x11\xe58\xfaM*0\xb0\xcb\xb7\x9a\x9e/\x8dW\xed=\xe4\xf0\x11(\xf5rB/P\x96\xd4\xefYQ.\x18*i-\xf1t/\xc9{\n\xa0)l\xe0wk5\x89J\xb4\xa1\xea\xf9 \x9c\xfe\x87\x1dPE\xa5\xf4'
        b"\x83'\x16_\xae\x1963NS\xed\xab\xdc*9\x9e\xb4\xaa\x13\xd67m\t\x82'\x92r\x07`(\xbd\xd8\xbc\xcc\xaa\x99\xef\xbe\xf1.\xf1?\x89\x1d\x19\xa2\xdaV:\xa5\xcd\xee)\xab\xa0\xd6\xd4\xa8a\xf9\xd6\xcf\x00\x0e"
        b'\xf2\x00\xd6!\x80\xb3\xfb!\x97\x85\xa8\x84\xb6\n\xf14\\\x07\xc7\xdfm 1\xf3\x8chld\xb5\xf6b\xda\xe7\x03$\xf5\xf3\xb6\xf1\xb2\xe2\xe2w\x99\x87\x01p\xd6:\xc9\x951\xe4\x0eH\x9a\xcf$r\xfd6E\xd5u'
        b'"@\xf1\xba\xdci]\xe81\xf8\x9c\xc8,(i/\x81"\x8dz\xd4\xdf\xe7/\xa2\xf7\x7fC\x10\x1a\xd0\xd45\xac\xb9\xa4\xa0\x0cf\xc1>)\xe3\xdc\xb8;k\x08ly\xd3Cd\xd6+\xe3^\xea\x8f\xe7\x9e\xfb\x81\xc7'
        b'Cy\xfb\x02\xd6\x8dZ\xef%\x88\xed\xedg\xf3\xe4~\xe3\xb3?\xc9\xfdL%\xca\x84\xc0\xf7\xcc\xa5lN(\x94\xa2\xc6{-\x8c\xa0`\x90\x1av]\xbb\xe16\x93\xaeD\xeaw\x17k\xc6c\xdbC\xaf;\xacv\x1f}'
        b'\x15\x0f\xda\x02*\x83\xe2\x1c\xb2\x9e#\x12|L$J\x8b\x84\xa5\xd2!\xaf\x1e\xc7\xd0o\xe4\x8d\x13\xc7\x84\x03\x8f\x12i\x8f\xf4\xe1\xc7\xe7NU\xddn\xfc\xdb\xa7\xe7Ap\x85Hn\xf6\x12\xb7n\xe8v\xfa\xce\xc0y\x97'
        b'\tU\xe9\xcem\x96\x14F#|S-\xbf\xbew\x14"\rO\x97\x8cci\x19\x86\xba\xd5\x9b\x9e\x9a\xf0C\x83D\xa4>\xe6\xc6y0\x93;\xd9BQ\xe9\xf3c\xd3\x18%0:p\xb6\xd7&\x94\x85\xa9EE>\xe8'
        b'}\x88\x04\x94#\r\xc96=sK\x9e1\xe9\xa3\xa7\xb2\x84\xef\xbb\xbeT\x8b\x88j\x08F\xbdM\x08O\x0er\xb8L0\xcf\xae\xd1\xd7\xa2Im[$x\x023\x01\x02]\x81\x8f<\x1bE\x0eW7T\nI\xc9\xb2'
        b'\x80\xa7\xb46\xf48\xdf4\xdaC\x95\xf4\x86\xba}\xae\xb9B\x86\xbc\xc3\xad\xe3/e\x88\xd0\tm\xce\xde\x97\xc6\xed\xd6\x8a\xc6\x04g\xc1\xd9\xc6\xa9\x0fP\xb7:f\xa5\xb6\xe3\xef\xa8\xca\xf1M1\x06pi\x11\xa4\xcb\xf7'
        b'0\x04\x8d\xf4[}\xf7a&eA$\xff\xfc\xf2l{\x807p \xee&g\xfd.\xdb\xd7XB\x04\x9d\x88\x8fX\xcd8\xef|h\xda\xfe\x1d\x16\x91(0\x06\x9a\xf4\tVvO\xfc\xf6\xb4\x13\xa3\x02\x8f\xd1\x05\xff'
        b'\xdb\x05\x19"k\t\x90wY\xed\x17\xdc\xcf\x1dOa8F\xd9\xef\xd1<\xb7\xd9\x827N\xd7\x7f\xfeTt\xeb\x92 ~r\xdc\x94V\xb0\x96ev2>S*\xb9~4}\x18\xf87\xf3\xfdt\xc6\xcb\xca\x0b0\xbd'
        b"E\xd0\xe8#\xd9<Z.\xf3Q>\x1e\xee\xe0\x1c\xe0')\xcb\x05\x01g\x89\xdb\x11\xf0\xa6\xf6\x1e$\xec@2\xb4\\\xd5\x9f\xb0}\xa4\x01\x8a}\x94g\t\xf9iN&\x1a\xed\x07B\xb1A,\xdf\xc1\x03\xaa\xe4\xe6\x88"
        b'\x1e\x9f,"h\xec\xdc.\x8f0.\xbb:\xbc\x87\xc63\xb4c)\xd2\xde\x10\\G\x0c\x1d\xfe\xd1a\xf5\xf0\xa4\x82=\xca\x80u\x9eG\x9b~\xca\x9a\xae\x00<\xa0/\xfaZ)\xf0\xd4Y\x08B\xdf\x94\x00\x1b\x9a\xecJ'
        b'r<W1\x16\xd1W\xb5\xacw\xa5\xe7\xee+\xe4\']\xaf"\x84\x8f`y\r\'\xe5\x0bc\xbe\xdd\x844A\xaa\x8c\xd2{o\xedkn\tQ\xf2\x9a \xaf\xaa\xe91\xfb\xa2~\x00\xac\x16\x8f\xf42\x88{\x08\xbb\x9a'
        b'L\xc5\xb9LHtU\n\x83\n\x85\x08>\x9cc}\xff[\xaf\xc3HA\xa9\x1b0\x98_.\x89\xfd\x01x\x14\xf9\xbf\xc2\x15\xb8=T\xdbr\x8eN\xc0\xc3\x99\x19\x15_\xcd@\xd2^\x0b\x92\x1c\xe9\x17,\x19]no'
        b'o\x11\xe0\x0cT\x92N8\xd0\x04\xe6T\xe3\xff\xbf\x85\x8fj\xf7>\x9a T\xb3\xc3\x1b\xe9\xe8\xf4\x8e\xb0\xfcg\x02\xed`/\xb5/^\xd1A\x80\x8468\x84\xce@\xca\xefk\xff\xa8\xf5\x18\xa7h%\xe2[w\xc6\x16'
        b'\xd18\x1dw\x10\xe4\x1c\x03\x19\xb4\xbd"\x9c\xa71l$\x9c\x06\xdb\xc1=\xce\t\x16\xb6\t:y\x93\x97\xa2;\x1a\xffC\xd0\xe6P\x95i\x12\xb7-\x13\xb0)\xd8\x1b\xcd&\xdfic"\xc5>Tz\x14\xf0E\xf6\xaa'
        b'>t5\xc8\xce\xe6{\xcc\xb3=\x93\x85\x13v\x19\xa3>V\x93\xea\xadilvY\x88\xe6\xc8\xad-\xec\x0e\xe0V8\xbe\x02\xd1_\xd2\x0eQ\x1f\xb0\x18\x08\xabo\xc0!I%l\x95$\xd42\x7f\x14\x05\xd1\x03\x0cp'
        b'\xc7\xb5\xeb\x96\xff\x143\xc3J\xb2Da_X^\xe2\xe8<|\xdd:\x04\xad\xff\xaf\x99\x7f\xf5\x90`qa)e7\x9f7u\xfa\xc9d\x16\x10Q%1\\\xd7\xe3NC\x10\x1a\x84\x89]J\x1b\xd5\x1f\xaeU\xc1n'
        b'\xea\xf0\xf9U\x021o\xfe\x02\xdcW/\xe4\x16 \xacw\x87+H1j#\xcbAc\xc1\xb4\xb7C\x93-~\xc8-U\x11\xf2\x9dr\x82\x01\xda\xa3\x88\xdf\xd2*U\xcdo\x9b\x8b\x1a\x1b\x9b\x0c`\xc8_\xe1pR0'
        b'\xe0|+\n#\xd6\xe5\xdf\xec\xd0\x97\xb9\xa3\xbc\x18\xf4\x8bs\xccW\xe0\xe1M\xa47t*\xdd\x01n\xdc\t\xb9\x81\xf3\xaf\x86\xd6\x08\xf0tq\xd8 \x0b\xe7\x18BG=\x01V7\x0c$\xe7\xbe\x04/\t]{@\x07'
        b"\xd5\xa7\xa4\xb4\xcf\xf3\x80A\xa0\x1c^\xbdv\xc31%\x03\xbb\xeb/5\xec\xf9\xfe\x13\xe1\xf1q-&\xd6\xf1\xea\x9f0\x1d\x01]D\xf0\xe1S\x85\x10\xe2\xb9f\xac\x88\xb9\xbe\x1d\x0f\xdfZ'\xba}\xa0\x9a\xc8Z\t\x95"
        b'bP\xcd\x1e\xb8S\xbc\x87\x14\xdet\x9c\x07\x07]\xd6#\x02O\x9a\x18\x0c\xc3BTVh}\x19\xe6\xdf\xa5\xa1\xfe\xee\x95U\x93\xb7\x1d.Lv4\xe9\x86\xca\x7f\xa7\x8a\xcd\xc7\x87cU\xdb\x17%\xd0\xa5y|Y\x18'
        b"QY\x8d\xb7-\xe0\xc0\x1e\xa8'\xf0#\xa1\x83\xdep\x96\x13\xca\x1fp\xf1N\xe7\x9e?\xb8\xacq9\x1e\x00~\x80\xda\xd4]\xa1\x00z\xe5J\x9f\x86Js\x85&\xf7l\xb2\x02\xf5\xe9\xd2\x9d\x9b\xab\xcc\xe19\xe0/S"
        b"b@\xcb\xa3\x82'\xb5V\x90q\xfc9\xdb3\xee\xea\xb1\t\x91\xb3\x95!m\x85\xac<\xa1Wm'\xfd\x98\xe6\x06\x95\xbcM'&+\xc9\xdd\x9e\x97\xe3\xd8\xf4\xea@M\x00\xea3\xc8u1v%7\x90\xb0\xfd\xb1\xe7"
        b'\x97f\xc3ui\xab\x03"\'\xc7\x9f\xe6\xdf\x18\x06\x7f>\xebZl\x99P\x1d U8\xff\x01 d\x00**E\xf2\xf8w\xb5\xfaS2\x0b\r\xea\xa2\x9ac&\x89\x08\xdf\xbb}\x8e\xb1\xab!9]n\xc5\x9eg\xdc'
        b'\x95}\x85\xf2\xcc\xde\xbd.J\x80\xc5|\xc8\xfa\xa2c\xa7c\x1c\x98\xc8\xe1R\xab\xa14\x00\x15\x03@\x83uJ\xb00\xf4\x14\xf8\x94\xf9\xfe\xb0aL\t\x81\xfa\xd9K\xc1Oh\xb9v\x18\xf6\xd5e\xa0-$\xa95:'
        b'~\x83\xed\xa1\x1e\x93\x84v\x80ZQ\xa0\x1d\r\xa3.\x916\xcd\xa1\xf5\x93\xe6B\xaa\xc6s\xf7\xd8SK\xb0I\x16\xd4\x82\xa3\xb2\xae,\xfe\xb1\xd6\t\x18g\x16\xb5+\x84\xa5\xb04s/\xb8\xb9\x89\x87\xf7DsG\xe8'
        b'\xcdF"k\x01\xe8e}\r]^\x8bDSc8\xf1\xbcZ\xa6O1\xa3\xd2\xc8#>c\xa10\x9c\xf5\x8d_\xf41\xd7]\xec\xc6$\x0f\x84>\x16\xb8A\xf7\xa5\xf8G\xcbF\xd9\xafxR\xe0\xb5d\x1d\xa8\x8d\xaf'
        b'\x06\x1a\xa6U\x826.l\x95\xa5\xa1\x94#\x1d\xd7\xb4\x8a,\xdd0\x9cUZ\xe1\xf7`\xfd?\xf5\x82\x9e\xb8\xaf4u\x13&" &\xe8\xf30\x0f\xa6{\xa8\xf6s+\x17\x19,\x0c\x9d%\x9cS\xcb\x968BL}'
        b'\xdc\x1f\x01a/u\xe7z;\x13\xf2:\xb1\xa2k\x15\xd1:\x15f\xcd\xa9F"OH\x97\xecR\x02A1?r\x9a\x8bb>\x83\x80\xec\xddG\xcb\xad:\xaa\xbc`\x14\x12v\xbe\x0b\x05(4\xb8\xc3\xa3NP\xf8\x15'
        b"\xee?\xce\xe9\xcb\xc69\xd8\xa3S\xea\xcf\x17\xc1\xb6&\xae\xac\x95\xd6(\xe0\x93\xf3\xc1\x96=\x9bwv\xd9C\xd6\x87\x06\xf7\xd3\xb3\xf8w\xcc\x01\xa3\xdaeevs'\x19\xbf\x1d\xd3\x184\xcf\xff\x18\xd8Ncyr\xc8"
        b'\xd2\xfe\xcc\xfe|\xdfb\xf6M\x0fs\x9dd\xf0mv\x0e\xe6|o\xea\xdab\x02\xc7></\x88~\xd51\x911f\xdc\x1d\xc4Z\x1d\xd7\xe1\tm\xbd\xa8\xda\x80\x0f\x93\xaaC,\x9c\r?\xca\x04\x01\xf26\x8f\xa7\x8e'
        b"\xab+s\xe4\xd6&*\xc4\x0e\x9f\xc0P\xd5G\xb2!\xaa\xd5+\xb9]\x16\xed8\t^\xb6'\xd4\xe5\xba'\xea\xdd\xbd\x9c\x98\xdb*\xede[k\x9aa\xa1\x8a\xc6W\xb2)\xc3w\x9c`\xccK\x98\xacm,\roq"
        b'm\xb8R\x0f\xd3\x8e\xa1\xec\xd2\xc51\xd8&\xe9@_x\xcc\xc7\xe0\xc5\x02\x1a\x1a\x9f\x15(\x1d\xbaE$\x0c\x7f\x1c\xad(P\xd0\xb9\x0cQ\x16L\x90\xdb}\x97h\x12\r}0\xc3\xef\xdc\xb3,d\x8bDF\xd8\x85\xf6'
        b'~~\'\r\xd7\xdb\xd8\xf91\xa0\x9b\x1d\x02)\xaf:\x06M\xef\x19\xf6\xa6\xcd\xfeP\x8ar\xaa\xca\x0b\x1b\xf1\xc9\x8fj\\\xed\xaa*\xd1\xcf\x8d^\x86\xc2\x0e\xeb\xb3\xac\x910\xb4\x08~\')"E\xe6t\xef\x12D\xd9'
        b'\xdd\x0fm[\xe8\xf5\xd4W@\x89\xca\xbb\xbd\xd2\xa4\x1b\xe8e\xd1\xcc\xe2g\x1c\xef&\xe9\x97\xa6\xb4&\xb7\xa7\x93L\x0e),\xca\xcc\xe7a#\xf8w[\xef-a\x90m\xe1\x0b\xe8\xad\xc9&\x1a/\xb9\x07\x0c\xc1\xe6\x02'
        b'\xbc\xb1\x87\x98\xd0Q\xb8\xb4\x95\xd9\x16Q\xcd\xf8\xe5\xe9\x97\x87\xfb_Z\xb9\'|=\x02\x8ft{\xfc\xe2\xc4\xd7Ar\xf0\xfd\xe2\xd1\xder\xe1\x86B\x02q"\x03N\xd98\x16\x9b\xc7\x19\xa2\x9c\xb4\xf5\xb1nI\xf2\xc3'
        b'\x0e\xa8q\tO\xc9\x85G\xbe\xf4,\x05\x83\x819\xab\xefd\xed\x17\xba\xed\x08\xe3GQ\x07\xd2\x16G0Y\x15!\xdb\x0cmH\xb5P\t\x1b\xa0S\x7f\xb7\x1e\x04\xd5\xa7M\x8f\xcd\x0eB\x8d\xf4L\xd6\x06\x85\x1e7\x14'
        b"\xd5\x01\xed\x0e\x91\xc8\x91\x99'\xc9Db\x01q\x9dZq\x9b\xf7\xa2\x11\xfc\xf0\x9a,)IV\xa3\xb4\xad$f\xec\xc7\x1f\xbbFf\xac\x93+Qe\xe5\xf6%\x0c\x9b.\\-\xb7\x88\x01\xa1\xc5\x15Y\xc3u\xb8J\xf8"
        b'\n\x96x\xf9(\xa6\xda\x02<\x1c\xe6"=y3\xe5\xef}\xd7%!\x1b\xa70\x8c\xcft\x8fx\x99\x1d\xe7H(\xe2\x9d\xfa\r3\xc9S\xfblV\x87\xfd`\\\x8d\xe6\xa1g2\xd8\x1c}\x15\xfb\xb8X\xb9+s\xaf'
        b'3)\xf8\x03\xf8mT \x05<\x15\xe4\xaf.\xc2\xc2\xbe\xa4\xd3\x88\x1a\xee\x80\xeda\x07#\xe6\x88\xf6K\x00\xea%\xc1*\xcb\xde\\\xea\x07\x07\xfe\xb8\xc2\x06\x9a\xe1\xbc\xb4\x94\xc3\x94k\x95Q\x87\xac\x81\xbd\xcf\xf7\xc0\x88'
        b'\x1d\xae4\xb9\xc0\xfd\xb8(^/\x07\x9d\x8c\xec.KkpB\x03\x0e\xc1\x1a\xd2M\x1eD\xe4\x0c4\xf8\xf0m@k"A\x88\x8f\x83\x8b,q7\xa2\xf0U?\xb4eO\xd8\x1a\xce@\x1b\x88\xe3\xb1M\x18\x05\x96$'
        b'\xa2\xd5P\xfdu-\x14\x84-\x92\xebY\xd3>\x02\xba\xa0\xce\x17!\xa4DG4\xedyO\x8c\xf0\xf6,\xe9\x9dl(\xf5\xfbq\xa1\x1b\xd7]8\x9c\xc5\xe9\x03q\xc2Z\xe97p\xed\xc68\xfa\xd0e\xe7\x91\xc4\x00\x0b'
        b'?\xdaS\xd4@x\xaa\r\xb1\x9d\xe6?\xdd#\x19\x0czG\xf6)\xb4\xad\x04c\xf3\xac\x19\x94PX\xed\xb3CRfjy%1\xd0C?\x1f \x8b\x05 \x94\x08\xedX\xef&\xe3\xd0a3sjIj\x18\xf5\xa4'
        b'\xaeB\x01"\xfc\xa6tp\xfc\xfa\\\xe2\xf6\x90Moa\xe7l\xd1\x7f\xf8\x95W\xe6Fy\xbd\xe9\xc6\xb3\xb5\xb8e4\x1b\x08\x92\x07\xf6\x923\xbf\x98l\\U>\xb6h\xe7!!o\xe5|\xe93\x92^\xf4\x99_\xfc'
        b'\xd7\xb5\xe9ELE\xac\x96\xfd!iD\x0c\x1a\xd7\xdev\x18\xb9a\x83\xabx\xba\xc6)\xb3\x13\xa6\xb3\xd6\xb9\x08\x83\xbdI\xd6\xc3\x7fM\xd6y)\xe5\xb40u\xbcj\x83g\xa7m\xf9V\xaas/\xfd%i\xaf\x9f\n'
        b"\xa4\xfd\x87\x93Xe<\xa8|\xe2\x88z\x8c:aAyS\xa5}s\xd6\xdc\xa7#\x7f\xc7\x00\xef\x9e\xa1c\x11%O\xea\x87\x80/\x96{n\xa2\x92@\xd7\xbd\xa7\xd0)'n\xf1\r\xc2\x8a\x19o~\x1dA0\xba\xcc"
        b'\xa0x\xfc\x18\xfe\xbe\xecc\x00\x144c\x89u\x13k\xc8V\x9bz\xf9\xc2O\xe3\xd1\x7fd\xd3\x05ZP8\xee\xc9u\\\xe6\xa4\xef\x81B\xa0\\{%]\x850]\xf1HE\x9cg\xc3\xc2\x97\xb3\xa5PK\x1a\xb6&'
        b"\x16e\xfeiv1\xdb\x1a\x83\x88'\x8b\xbc\xae\xda\x12\x14\xde\x05W\x98tu*\x9c\x9b\xe9t\xb07k\x1d|Y\x8f0\xd8\xd8\\\x9c\x0f\xc8\xf5\xd9@\xe7\xd3\x84\xb93\xd6\xa4r\x80\xddCj\x05\xc2\x0bhc\tb"
        b'\x85\x0ew\xbb\xf5cz2;\x87Mz@2\xbb\x1b\xb9\x84$l\xf3P\xd1p\x8e\xd6\x01\x93\xdf\xf2\xfb(\t\xe4v\xb0\x14\xd9\xed\xb2Ov\x06\x98<9:\xc5J\x0fKWq\x9a\x0fQ\x0c=Tr\x14 \x90\n'
        b"\\\xf6\xbe\xb6\xfb\xbd\xb9e\xa9\x88U{O,6\xda\xd1\xee\x17\xa8\x82\xa0Q\xe97\x924\x82:Y\xb3\xa7\xf7O6\xc0\xce\xa7\x82\x01\xa4\xe4\xb8\xef\x12\xa5\xf0\xe9;\xd8\xb8\xf4}{\xcf'Mh\x05\xc2\xec'\xbd\xf3"
        b'\xf7@\t\x8d\xbc\xb0lS\x94\x99\xaf<\xf8\x9eX\x90\x1a\x14\n\xf0\x91)\xfd\xbbB\x15\x12\xbeG\xf3\xe4\xa5\x8c\xda\xf4\x9e\x9fT\xa1\xaa\xf8o\xac%\xd8l\x13\xf7@\xe8\xe7wA\xe7\xe3\x08\xf2\x9d\x02;%ct['
        b'\x1f\xd4\x0f\x8d\x88\xd1\xe3\x9a\x80\x02\r\xa2uVF4\x91\xea\x90\x07\x82n\x836\xe9\xa5\x0b\xff\x9a\x15\xd2EDYO\x80"}\xe92\xbe\xd6`\x89gU\xe5HG\xfdL\x0e\x11\x8e\xf6\xc6\xcfa\'+5\xae\x9b\x03'
        b'Jx\x1d\xe5\x11]\xd6Z\xd4\xcdO\xd6\xd7\x1a\rw\xb7\xdf\x0f\x82M\x7f\x02"\xa5-Y;\xfe\x03\x08\xf2\xf4z\xfeh\xac$\xec\x88w\xb4\xd5\xe9ip\xacJ]\x84B\xff`\xa9\n\x84\x90\x8f\xd0\xd5\nH\x8a\xf4'
        b"\x8d\x00\x8a2\x03;\x8bX\x9e~\x14\xb0j>L\xf0ly\xedK\x9c8\xffX-&\xf4\nE\xf1\x16]\xf5\xf9\x03V\x96\xdc\xd7e\xb9\xf4\xdd\xde\xdf28'\\\xab@\x94)L\x90\xf4\x040\xceuc\xc9\x9e\xf3"
        b'\xc2\x13N\xc4\x99\xdc\xf7\xd8ae\x00Q\xe0\xfd\xc6\x96\xe0\xcf\xd7\xee\xa9ynM\xb9I\xf3\xb8\xe9{\xcf\xb5\xc2X\xeaH\xb7\x96\x8c1\xe5]\xd0\xf9\xf7\xf6\xf4\xe8\xa5*\x84B_\xa8p\xcbAb\xb7\xbf\xd1\xc3\x8e\x85'
        b"\x15\xca\xf0\xe9\xfc\x8d\xa3\x0b\xa3'0\xb0\xb5d\xd8\x0f\x18j\xfd\xf7\xceB\x94\x15\x98\xab\x0bq\xd8\xdbC\x99\xa5\xc3\xd4\xecc\xfb3\xaf\x1e~?\xe8\xee\xd0\xcb\x87^\xd0\x10R\x08\xd8\xfe\x19\t\xcd\xd0\xe7\xc7\xb3\\\xd7"
        b'\xbcL\xc8\xae\x96\x04\xc4~\x15:\xac\x1aQ\xd7\xbcuy\xb4\x84\x86-\xc6-/\x9e\xf4\xd2\xfb:\xf1\xdcKz!K\x19\x11\xc7\xfc\xc4!n\xe03\x1fN\xa8\xa0\x9e\xef\xbapgo\xad\xcf\n["@v\xb9\xea*'
        b'[\xe4XU\x18;\x83Bf\xc0\xea\xca\x02\xc7\xdc\xbe9_\x89ra\xad\x1a\x10\x05\x80\x05\x8c\x0f\rY\x1f\xd6i\x87\xb5j%\x0b\x03h\xa8\\\x88%\x8c\xe5\xb2\x99\xd9n\xe4\x12\xbak\x1b\x87\x18y\xbd\x03K\xcd\xd2'
        b'\x9aGa\xcd[\x08D\xc2*\xa2\x8f\x0b\xc2\xbd7\xee\xb4m\t\xefR_;\xa5\xa3D\x0bQ\xc4\x1e\x88\xf5\x07\x83}l\x8d\x08\x99\xf3\x9c\xdf"1q\xfd\xe4\x1e\xdf\x84\\\xf2Y\xe3@\xa6\xff\xfb]\xaff\xa6\x0c\x12'
        b"\x1f\x03\xbc\x9f\xb2\xa9D!\x92r\xa4\xe7d\xb2l\xb5\x83gB'\x16V\xb1|\xeb\xb2\xdd\x8a6F\xb2\xdf\xe8\xab\xe2\xf6\xb2\xb3\xbez8\\\xadqM\xd3T\x7f\xf02Y\xe12\xf0k\xb43\xe7O2\xc4\xe0\x0f\x9b"
        b'o|\x17\xba\xf4\x9bn\xe3\xac\x7f^\xbe\xde\xd3\xc8\x8dO\xf7\xb2\x81S\xc7s\xae,B\xaa!k\x9a\x84\x9fr\xe6\xfcP\x95\x93\x96\x83DP\xbbOyDG#\xb4\x13\xe0\x15\x87\x85\x16\xd2\x98\xd4\xa8\xdd\xcfU\xcb\x98'
        b'\xe3pPc\xf9}5@k]d\xe6\xea\xa1]?\x86l"\x88\x7f\xc9\xc7\xe1K\x9a]\xa2#\xbe\xc2Y\x0f\xdc\x1dS\xfb\xf1\x92}rpk\xf6\xbc>:\xe7\xf6N\x87\xcf\x9b`\xea\xf2\x1f\x11\x8cg\xa5/:\x84'
        b'\xde3R[\x12+j\x84\xe3\x17ot>m\x97\xc2\xa3"\x93\xd7>\x1c\xc4\x1e\x84E\x89\x10\x18;]\xfe\x1eD\xee/K\x14B=V\xc1\x01\x1a\n\xf1^\xfd\xc2P\x1d7\xf4F\x82\x03{*L\xb4\xf3\x10X\xed'
        b'\x9a\x91\xb6\xa6\x11\x15\xe5p;P\xd6h\xe23e\xa7\xe7&\nhC/7\xc42\xaaC\xa5\xe3\xdc\xe5!3\xdc\x04\xad\x98L5\xeb\x17\xbd\xb5\x01\xe0H\xd9\x80\xbb\x86\x8e\x01\xa2\x81\xb9\xd8\xb2\xdbV|\x9e\xa9\xf3x'
        b"\xab1\xbec\xb9'\xd9&\xc4\x1dd\xfd\xd2\xb0\xb4\xe3\xa8\x01\xcf\xd8\xe6\x96<u<\xc6\xef\xeab_v\xe5\xb9_g\xfa\xbd\xd2\xbe\x07\xe8W\xb6B\xbdO6\x94\xe4o\xa9\xf7\x89/o\x83b\xec\xaa\xad\xbb'E\xd0"
        b'\x84n\xec\xd0\xda\x0f\xbc\xe1\xee\x93\xb0\xf4\xded\xbe\xab\x91\tH\xa2\x9a`K\x95\xad\xc6\x1fm\x1b\xe4o\x12\xdd<O\xcb\xf5d\x12a[\xd0\xca\xdd\xee\x8d\xf5l<t\xf9\tGz[\xf6(\x06Ee\xab\x9b\xd8\x05'
        b"\xa7\xfc0\xa8*\xf3\xc2\xfb\xbb\xc3\x12X\x00\xc5\xe1qK,x\xd5n<mIp\xcb\xdb*'\xea\xb8\xe7\xcc]\xb2Yu\xdb\xcbs\xddM\xb7\x90\x89\x93\xd0\x01\x9a\x8d\xa5.\xbc;\xf2\xef\x12{\xe7\xb1q\xca\xf6\xe2"
        b'.\xdeb\x10\xcbL\xd3\xabs\xfaz_\xfaJ\xee\x9e\xd1\xdd&\xea+\xb6S7U\xb4\x8a\x88\xaeI\xdf\xce\x04\x90\x88\tN!k\xa0\xe3@\xca.w\x1f\xe6\xfc\x10\xf2\x01OfMc\xe4\xfc\x87\xf4\x84\xe8n\xeca'
        b'e\xd3\xd9\x02G\xbeY\x05\x15\x13z\xf7\xcf\xbc\x9d\xcb\xa7\xc2ly\x9b\x14.\x83\xae&te\x9d\xaa\x03!\xa3.\x0b\xa4\xbd\x04\xf0\xd5\xfaPi\x98d}+\xf5\xf6{^\x16Q\x85\x15hDjD\xee\xe3\xd4\x8e\x06'
        b'\xc0\xe52\x07P\x81M\xeb\xb0\xfc\x8dc\x19\xf6\x04b;\xdf\x03\xcd\xd3\xb3\xfcZ\x15>\xe5\x8b\x08M\xe9v\xad\xa4w\xc2\xa8#,\'#\xa0.\xb27\xe7,\xc2\xd9p\xea"\x84Y\xfd\xe3U\xe9t\x8b6\x1eK\x03'
        b"\x85\xf8\xb2\xb6\xc0\xd8a7\xebmJ\xac\xb4[\xf1'\xa5\x1f{zS\xb1\x1e\xf2=V\x86g\x19n+\n\xd4\x17HF\xaa\xfe\xe6\x1d\x1f{\xbb>a\xd3\xee\x18\x8e\xf9Z>*\x8cK&\x90\x1f\x7fc\x19\xfd\x06d"
        b'\xe1\xe6-^o8\xcd\x19\x19\x80\xbb"\')\xeb\xba\xc5\x11\xf3|\xfb\x9a]\xe8\xe4 M\xd3V\xc2\xf7tq\xbb\x8c\x97x\xb8B;\xadE\x11\xa2\x92\x17\xca\xdc\x7f\xb1\xa3x\xba/!\xf9\x8f\xbdM\xf2\xb8\xa7\xdaL'
        b'\x01S\x86\xbf\x83c1~\n\xa0\x964+\x1em2\xb7\x10[`RDt\xaa1\x1f\x93\r\n\xfe5\x0f\xf1=<\xef9\xf3\xdfG\xd5q1\x14\xfc\x81\xe9.\xd5\xa5\xeb\xe8\x99o\xb7tz%\xd3\x0b`\xb3\xe1&'
        b"\x0f<_\x96q\xeb\xd0\xecg\x7f\xec8\xc5=7CP\xe4\x1c\x1d\xaa\xbc\x03\xf4\\\x05'\xa4\x9f\xaan\xd1\x92\xb9_\xbf{\x14\xaa\t}\x05p\xefd\xbd\xe2\x81\xcb\xb7\x99c4\x18\t\x15\x8a\x86\xc6\x11\xddV)g"
        b'H9Y\xd51f"\xbf\xe2\x9dA^\xf3T\xe8\x9a<\xfb\xfb<\xc1,\x15\x9ab\xd2<y\xa5\x85\x05\x88b3\xfe\x18\xa5\x93\x9aCAA\x05\x84\xda\x9frH\xc6\xbf\x03\x1b`\x88\xbaT\x191L\xb0\xed\x0cS\x07'
        b'\xc5\x02\x11\x90\x00\x16c\xa7^\xcba\xa0\x1d\x1d\xe5h\xbf|\xb5\x86\x8d\x06\xa3W]b\x04\xd5\xb8\xa27JF/\xddA\x81\xf6\x01\x07\xc9\xd3\x99\xd3\xca\x05\x87\x02\xc0\xf1\xf8\xde}\xf2\x11\xd8\xdfZe\x83\xd3\xa9\x97\xb4'
        b'P\xdah\xe3\xeb\t\x08\x16\x1b\xd9\x8c-\xfa\xb8\xa9.`\x87\xc2jB\xdd\x14\x92\x0c\xc6\x82\xc2p\xdc\x014\x03p\xd2\r\xe4\xa2\xaf\x07\x0b\xbc\xb7\xda*?zwS\xea\xd6\x0f\xbe\xde~-\x1eR\x02h$\xea\xd4E'
        b'\xef\xcd\x90\x18\xcd\x85\xf7x+c\xe0\x0f\xc9\x96\x08\xcf\xb0\xbaX\xf5\xea_\x86\x8d\xbe\xec\xf5\xd9\xe0f\xa2\xd2|n\x8f\xa5\xd5f\x15\xa0\xc7S\x1f\xb5\xa6\xe5\xa8v\x129\xa6\x88r\xba\xf4\xb7\x90\r\xfe\x17\xd5\x9d\x84\x8d'
        b'\x1b5\x9ax\xf4\xcc\x17\xb9\x93\x8d\x03\xbd\x02\x1c]\xa2H\xcbG\x9e\xcfE$\x1d5\x81\x95\xe4\x9a\xf4\xadk\xeel/w2D\xbc\x8aP+\xb3ox\x04Z\xde\x0c\xbbt\x82\xbe\x19\xa23\r\xf2\x0f@\xc0\x8c\xc4-'
        b'R\xf2v\xe7\x15\x1f\xd0\\Jum8|\xc98\xf5j\x00u\xf1\x856\\z1\x1d\xd2\t\xad/\x8fH\xa0\xb3$i`\x17\x1bq3\x07\xda\xa33`gw~\xa9\n\xda\xec\xee\xc3\xfeHM\xe8^c6WJ'
        b'\xf8\xfb\xb5\xd9\xf7\xc6\x18&\x12\x9d\x96c\xb9\xde\xb4\xd1\xdf\x02\x8dy#dv?#e9\x84\xdc\x190\xca\t\x11r\x92\xd2QgY\t\x99w\xef\x05\xb3\x05J\xf9\xfc\xfa\xcc%\xbf5\x8c\x9bH\xc3\x10\xbf\x97\xbd\xa5'
        b']\xc1\xf7\xb8?5e\xd8\x9f\x93r\x9aDv;\xfb\xe7\xf0_3\xf9\x86\xf3\x81#\x14\x81\xfa\x1e\xb2\xd9O \xd0\xb0\xf9\xdc>4O\xfe\xd7^\x18\x82&u\x86+\x16\x99\xfb\xda\x9e\x8c\x01\x1b5\x0b\xfb\xab\x12_i'
        b'\x9d\xfd\x85\x84a5\x8b\x04\xc2\xd4\x03\xd0\xa2\xd5#\xfc\x7f\xf1\xc4\xbb\xc7\xf4:\xf5\xbd/\x17[X\x13\xbf\x11\xc1\x8b\x85\xe04 \x87dH\xe9\xdch\xc7\xcb\x95\xb1\xe2\xaf\xe2\xa98\x9e_z^\x12\x18\xad>\x88$\xf9'
        b'\xa7\xa4gs\xef8\x82h\xf7K}\x1a\xb1\xf0\x9f\x0eL\x15\xf2\x92\xcdc\x83\xac\xd3\x9c\x92g?p\xf4\xd1\xde\xd1p\x98(\x99e\xaf<\xec\x10\x08\xe4z%\x88\x87\x9a\xea\xbdK%\x8f\x9a\xf16\x82\x9d\x00\x8b\xd3\x84'
        b'h\x11u\x81\xdb\xddw\xe5\xe3\x0cQ\xbaqec\xd9\xe3\xde\x01\xef\xcd\x11\xf6|\x11\x9d\xa3]\xad)>o\r\x17\x83\x8b\xb1Q\xe6\xa8\xae,Rh\xe29\x9f\x84\xb0\xf0\r\x00\xe6\xb6\xa1\xa6\x8f\x05\x91\xbbE\xfb\xec\xea'
        b'\xcd\xd0\x19\xf1\xd2\x803_<\x04j\xd5\xf9F\xcb\xbd\x1cz{\x9d\xceO&^^!Y2nF\xb3\xf0\x0c\xdf\xe3~\x1at\xa2\xa2\x8a+\xdd*\xa0"\n>@\xf5\xb3\xb3w\xa2\xc3!@\xdb%\xbd\ry\xd4_'
        b"\xf7\x84\xcd\xa6M^'\xb6\x14\x18\xb3\x07\x93\xf1\xd4`\xd3\xb8\xb8&\xc3!q\xe2\x86w\x85\xa1\xdas\x9a\xcf\x8a\xdag\xaeHxg`D\x15\x84\xb5\xfd\xcd\xc3X\xfd\xccER\xba\n\x1c9\x02\xd1\xe2\xbe)\xcc\xa0`"
        b"\xf7\xa7\xe7\x9c7\xd1sP\xd7\xa9\xd4\xe5\xf5\xfa\xedwW\xdfW\xedc\xbbL$\xf9\xfaP\xa0\xad\xad\xd4g)C'\x90\xda\x11\x9c\xdf}\x92\x9f\nys\xfa<,\x10\xea\x079\x0eH\xdf\xe13\x18\xc1\xfb\xa0>\xfe"
        b'\x1f\x91\xb6\x04,\xd8\x90\x84<\x9b\xe6;\xb8v\x05\nU\xe0t\xc6\xa6\x1e3\xecM\xe2\xb32hw\xcb\xa6Au\xc56{\xa3\xee\xda\x82\xd8M\x89\xbd\xb7S\x9ck\x99N8[\x9b\x1a*rwJ\x82\x8a\xd4\x16\xcb'
        b'Im\xfc\x1e\xb4\xb5KZe\xda\xb0\xe27\xe5\xe3\xe4\n\x8b\xce`2\xcb\xc4!\xc00Jl\xfd!\x08\xd8\x11\x9f\xd6z5\xb7\x07\xe6\x14$=\xd1\xf7q\x99*[O\x1fFU<\xfc\x89\x0c\x1b\xeba\xad\xa2\x98\xa0'
        b'\x88\x1cEbuu\xef\xa1\xbd\xd0!\xd4\x9e\\\xe0\x0b\x03S\x97~\xc1\x83\x1e\x9elB\x8a\xd0\xf4\t\xf0 \x90V\x1d\n\xa6\x83\x88{N)\x04\xda\x07runtimer\x03\x00\x00\x00\xda\x08__nam'
        b'e__\xda\x08__file__\xa9\x00\xf3\x00\x00\x00\x00\xda\x16<frozen fintech.swift>\xda\x08<module>r\n\x00\x00\x00\x01\x00\x00\x00s'
        b'\x1d\x00\x00\x00\xf0\x03\x01\x01\x01\xe5\x00 \xd9\x00\x0b\x88H\x90h\xf0\x00\x00!\\E\x0e\xf5\x00\x00\x01]E\x0er\x08\x00\x00\x00'
    ))
